package com.qmth.paper.library.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.paper.library.business.bean.result.SelectResult;
import com.qmth.paper.library.business.entity.PaperArchives;
import com.qmth.paper.library.business.entity.PaperArchivesType;
import com.qmth.paper.library.business.mapper.PaperArchivesTypeMapper;
import com.qmth.paper.library.business.service.PaperArchivesService;
import com.qmth.paper.library.business.service.PaperArchivesTypeService;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.enums.ExceptionResultEnum;
import com.qmth.paper.library.common.util.ServletUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * <p>
 * 档案类型表 服务实现类
 * </p>
 */
@Service
public class PaperArchivesTypeServiceImpl extends ServiceImpl<PaperArchivesTypeMapper, PaperArchivesType> implements PaperArchivesTypeService {

    @Resource
    PaperArchivesService paperArchivesService;

    @Override
    public IPage<PaperArchivesType> pageData(Integer pageNumber, Integer pageSize) {
        QueryWrapper<PaperArchivesType> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().orderByAsc(PaperArchivesType::getCreateTime);
        return this.baseMapper.selectPage(new Page<>(pageNumber, pageSize), queryWrapper);
    }

    @Override
    public boolean saveData(PaperArchivesType paperArchivesType) {
        Long userId = Long.valueOf(ServletUtil.getRequestHeaderUserId().toString());
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());

        PaperArchivesType archivesType = this.baseMapper.selectByArchivesType(schoolId, paperArchivesType.getName());

        // 新增
        if (paperArchivesType.getId() == null) {
            if (archivesType != null) {
                throw ExceptionResultEnum.ERROR.exception("类型名称已存在");
            }
            paperArchivesType.setId(SystemConstant.getDbUuid());
            paperArchivesType.setSchoolId(schoolId);
            paperArchivesType.setCreateId(userId);
            paperArchivesType.setCreateTime(System.currentTimeMillis());
            return this.save(paperArchivesType);
        }
        // 修改
        else {
            if (archivesType != null && !paperArchivesType.getId().equals(archivesType.getId())) {
                throw ExceptionResultEnum.ERROR.exception("类型名称已存在");
            }
            PaperArchivesType oldPaperArchivesType = this.getById(paperArchivesType.getId());

            oldPaperArchivesType.setName(paperArchivesType.getName());
            oldPaperArchivesType.setUpdateId(userId);
            oldPaperArchivesType.setUpdateTime(System.currentTimeMillis());
            return this.updateById(oldPaperArchivesType);
        }
    }

    @Transactional
    @Override
    public boolean delete(String ids) {
        String[] idsArray = ids.split(",");
        for (String id : idsArray) {
            Long idLong = Long.valueOf(id);
            PaperArchivesType paperArchivesType = this.getById(idLong);
            if (paperArchivesType == null) {
                throw ExceptionResultEnum.ERROR.exception("数据有误");
            }
            // 已使用不能删除
            QueryWrapper<PaperArchives> queryWrapper = new QueryWrapper<>();
            queryWrapper.lambda().eq(PaperArchives::getSchoolId, paperArchivesType.getSchoolId())
                    .eq(PaperArchives::getArchivesTypeId, idLong);
            int count = paperArchivesService.count(queryWrapper);
            if (count != 0) {
                throw ExceptionResultEnum.ERROR.exception("档案类型已使用，不能删除");
            }

            this.removeById(idLong);
        }
        return true;
    }

    @Override
    public List<SelectResult> queryArchivesType() {
        Long schoolId = SystemConstant.convertIdToLong(String.valueOf(ServletUtil.getRequestHeaderSchoolId()));
        return this.baseMapper.queryArchivesType(schoolId);
    }
}
