package com.qmth.paper.library.business.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.paper.library.business.bean.result.PaperLibraryResult;
import com.qmth.paper.library.business.bean.result.PaperScanTaskResult;
import com.qmth.paper.library.business.bean.result.TaskStudentResult;
import com.qmth.paper.library.business.entity.PaperLibrary;
import com.qmth.paper.library.business.entity.PaperScanTaskDetail;
import com.qmth.paper.library.business.mapper.PaperLibraryMapper;
import com.qmth.paper.library.business.service.PaperLibraryCommonService;
import com.qmth.paper.library.business.service.PaperLibraryService;
import com.qmth.paper.library.business.service.PaperScanTaskDetailService;
import com.qmth.paper.library.business.service.PaperScanTaskService;
import com.qmth.paper.library.common.config.DictionaryConfig;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.enums.ExceptionResultEnum;
import com.qmth.paper.library.common.enums.RoleTypeEnum;
import com.qmth.paper.library.common.enums.UploadFileEnum;
import com.qmth.paper.library.common.lock.LockService;
import com.qmth.paper.library.common.lock.LockType;
import com.qmth.paper.library.common.service.SysUserService;
import com.qmth.paper.library.common.util.FileStoreUtil;
import com.qmth.paper.library.common.util.ImageUtil;
import com.qmth.paper.library.common.util.OcrUtil;
import com.qmth.paper.library.common.util.ServletUtil;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.json.JSONArray;
import org.json.JSONException;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

/**
 * <p>
 * 图片库 服务实现类
 * </p>
 */
@Service
public class PaperLibraryServiceImpl extends ServiceImpl<PaperLibraryMapper, PaperLibrary> implements PaperLibraryService {

    @Resource
    private DictionaryConfig dictionaryConfig;

    @Resource
    PaperScanTaskService paperScanTaskService;

    @Resource
    PaperLibraryService paperLibraryService;

    @Resource
    PaperScanTaskDetailService paperScanTaskDetailService;

    @Resource
    PaperLibraryCommonService paperLibraryCommonService;

    @Resource
    SysUserService sysUserService;

    @Resource
    OcrUtil ocrUtil;

    @Resource
    LockService lockService;

    @Resource
    FileStoreUtil fileStoreUtil;

    @Override
    public IPage<PaperLibraryResult> pageUnbindData(Long paperScanTaskId, Integer pageNumber, Integer pageSize) {
        return this.baseMapper.pageUnbindData(new Page<>(pageNumber, pageSize), paperScanTaskId);
    }

    @Override
    public int countUnbindData(Long paperScanTaskId) {
        return this.baseMapper.countUnbindData(paperScanTaskId);
    }

    @Override
    public IPage<PaperLibraryResult> pageBindData(Long paperScanTaskId, Integer pageNumber, Integer pageSize) {
        return this.baseMapper.pageBindData(new Page<>(pageNumber, pageSize), paperScanTaskId);
    }

    @Override
    public int countBindData(Long paperScanTaskId) {
        return this.baseMapper.countBindData(paperScanTaskId);
    }

    @Override
    public IPage<PaperLibraryResult> pageAbnormalData(Long paperScanTaskId, Integer pageNumber, Integer pageSize) {
        Set<Long> listSubOrgIds = paperLibraryCommonService.listSubOrgIds(null);
        Long userId = Long.valueOf(ServletUtil.getRequestHeaderUserId().toString());
        boolean isMatch = sysUserService.checkRoleIsAppoint(RoleTypeEnum.DATA_CHECKER, userId);
        return this.baseMapper.pageAbnormalData(new Page<>(pageNumber, pageSize), paperScanTaskId, listSubOrgIds, isMatch, userId);
    }

    @Override
    public int countAbnormalData(Long paperScanTaskId) {
        return this.baseMapper.countAbnormalData(paperScanTaskId);
    }

    @Transactional
    @Override
    public boolean bind(Long paperLibraryId, Long paperScanTaskDetailId) {
        PaperScanTaskDetail paperScanTaskDetail = paperScanTaskDetailService.getById(paperScanTaskDetailId);
        if (paperScanTaskDetail == null) {
            throw ExceptionResultEnum.ERROR.exception("绑定对象有误，任务下无该考生，请刷新数据再试");
        }
        PaperLibrary paperLibrary = this.getById(paperLibraryId);
        if (paperLibrary == null) {
            throw ExceptionResultEnum.ERROR.exception("绑定对象有误，图片已删除，请刷新数据再试");
        }

        UpdateWrapper<PaperLibrary> updateWrapper = new UpdateWrapper<>();
        updateWrapper.lambda().set(PaperLibrary::getPaperScanTaskDetailId, paperScanTaskDetailId)
                .eq(PaperLibrary::getId, paperLibraryId);
        this.update(updateWrapper);

        // 更新已绑定状态
        if (paperLibrary.getPaperScanTaskDetailId() != null) {
            PaperScanTaskDetail oldPaperScanTaskDetail = paperScanTaskDetailService.getById(paperLibrary.getPaperScanTaskDetailId());
            // 查询是否有绑定试卷
            int count = this.baseMapper.countByPaperScanTaskDetailId(paperLibrary.getPaperScanTaskDetailId());
            oldPaperScanTaskDetail.setBind(count > 0);
            paperScanTaskDetailService.updateById(oldPaperScanTaskDetail);
        }
        paperScanTaskDetail.setBind(true);
        paperScanTaskDetailService.updateById(paperScanTaskDetail);

        return true;
    }

    @Override
    public List<PaperLibraryResult> listStudentPicture(Long paperScanTaskDetailId) {
        Long schoolId = SystemConstant.convertIdToLong(String.valueOf(ServletUtil.getRequestHeaderSchoolId()));
        QueryWrapper<PaperLibrary> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(PaperLibrary::getSchoolId, schoolId)
                .eq(PaperLibrary::getPaperScanTaskDetailId, paperScanTaskDetailId)
                .orderByAsc(PaperLibrary::getSequence);
        List<PaperLibrary> paperLibraryList = this.list(queryWrapper);
        List<PaperLibraryResult> paperLibraryResultList = new ArrayList<>();
        for (PaperLibrary paperLibrary : paperLibraryList) {
            PaperLibraryResult paperLibraryResult = new PaperLibraryResult();
            BeanUtils.copyProperties(paperLibrary, paperLibraryResult);
            String fileUrl = paperLibrary.getPath();
            if (StringUtils.isBlank(fileUrl)) {
                throw ExceptionResultEnum.ERROR.exception("未找到图片路径");
            }
            List<JSONObject> objectList = JSON.parseArray(fileUrl, JSONObject.class);
            List<String> fileUrls = new ArrayList<>();
            for (JSONObject jsonObject : objectList) {
                fileUrls.add(paperLibraryCommonService.preViewPath(jsonObject.getString(SystemConstant.PATH), jsonObject.getString(SystemConstant.UPLOAD_TYPE), jsonObject.getString(SystemConstant.TYPE), false));
            }
            PaperScanTaskResult paperScanTaskResult = paperScanTaskService.getByPaperScanTaskId(paperLibrary.getPaperScanTaskId());
            if (paperScanTaskResult != null) {
                paperLibraryResult.setSemesterName(paperScanTaskResult.getSemesterName());
                paperLibraryResult.setPaperArchivesName(paperScanTaskResult.getArchivesName());
                paperLibraryResult.setPaperScanTaskName(paperScanTaskResult.getScanTaskName());
                paperLibraryResult.setCourseName(paperScanTaskResult.getCourseName());
                paperLibraryResult.setTeacherName(paperScanTaskResult.getTeacherName());
                paperLibraryResult.setTeachClazzName(paperScanTaskResult.getTeachClazzName());
            }
            paperLibraryResult.setFileUrls(fileUrls);
            paperLibraryResultList.add(paperLibraryResult);
        }
        return paperLibraryResultList;
    }

    @Override
    public List<PaperLibraryResult> toAbnormalPaper(Long paperLibraryId) {
        Long userId = Long.valueOf(ServletUtil.getRequestHeaderUserId().toString());
        Long schoolId = SystemConstant.convertIdToLong(String.valueOf(ServletUtil.getRequestHeaderSchoolId()));

        List<PaperLibraryResult> paperLibraryResultList = new ArrayList<>();
        PaperLibrary paperLibrary = this.getById(paperLibraryId);
        PaperLibraryResult paperLibraryResult = new PaperLibraryResult();
        BeanUtils.copyProperties(paperLibrary, paperLibraryResult);
        String fileUrl = paperLibrary.getPath();
        if (StringUtils.isBlank(fileUrl)) {
            throw ExceptionResultEnum.ERROR.exception("未找到图片路径");
        }
        List<JSONObject> objectList = JSON.parseArray(fileUrl, JSONObject.class);
        List<String> fileUrls = new ArrayList<>();
        for (JSONObject jsonObject : objectList) {
            fileUrls.add(paperLibraryCommonService.preViewPath(jsonObject.getString(SystemConstant.PATH), jsonObject.getString(SystemConstant.UPLOAD_TYPE), jsonObject.getString(SystemConstant.TYPE), false));
        }
        PaperScanTaskResult paperScanTaskResult = paperScanTaskService.getByPaperScanTaskId(paperLibrary.getPaperScanTaskId());
        if (paperScanTaskResult != null) {
            paperLibraryResult.setSemesterName(paperScanTaskResult.getSemesterName());
            paperLibraryResult.setPaperArchivesName(paperScanTaskResult.getArchivesName());
            paperLibraryResult.setPaperScanTaskName(paperScanTaskResult.getScanTaskName());
            paperLibraryResult.setCourseName(paperScanTaskResult.getCourseName());
            paperLibraryResult.setTeacherName(paperScanTaskResult.getTeacherName());
            paperLibraryResult.setTeachClazzName(paperScanTaskResult.getTeachClazzName());
        }
        paperLibraryResult.setFileUrls(fileUrls);
        paperLibraryResultList.add(paperLibraryResult);
        return paperLibraryResultList;
    }

    @Override
    public List<PaperLibraryResult> toBindPaper() {
        Long userId = Long.valueOf(ServletUtil.getRequestHeaderUserId().toString());
        Long schoolId = SystemConstant.convertIdToLong(String.valueOf(ServletUtil.getRequestHeaderSchoolId()));

        // 查询下一个待绑定任务
        List<PaperLibrary> waitPaperLibraryList = this.baseMapper.selectBatchData(schoolId, userId);
        if (waitPaperLibraryList.isEmpty()) {
            waitPaperLibraryList = createBindData(userId, schoolId);
        }

        List<PaperLibraryResult> paperLibraryResultList = new ArrayList<>();
        if (!waitPaperLibraryList.isEmpty()) {
            for (PaperLibrary paperLibrary : waitPaperLibraryList) {
                PaperLibraryResult paperLibraryResult = new PaperLibraryResult();
                BeanUtils.copyProperties(paperLibrary, paperLibraryResult);
                String fileUrl = paperLibrary.getPath();
                if (StringUtils.isBlank(fileUrl)) {
                    throw ExceptionResultEnum.ERROR.exception("未找到图片路径");
                }
                List<JSONObject> objectList = JSON.parseArray(fileUrl, JSONObject.class);
                List<String> fileUrls = new ArrayList<>();
                for (JSONObject jsonObject : objectList) {
                    fileUrls.add(paperLibraryCommonService.preViewPath(jsonObject.getString(SystemConstant.PATH), jsonObject.getString(SystemConstant.UPLOAD_TYPE), jsonObject.getString(SystemConstant.TYPE), false));
                }
                PaperScanTaskResult paperScanTaskResult = paperScanTaskService.getByPaperScanTaskId(paperLibrary.getPaperScanTaskId());
                if (paperScanTaskResult != null) {
                    paperLibraryResult.setSemesterName(paperScanTaskResult.getSemesterName());
                    paperLibraryResult.setPaperArchivesName(paperScanTaskResult.getArchivesName());
                    paperLibraryResult.setPaperScanTaskName(paperScanTaskResult.getScanTaskName());
                    paperLibraryResult.setCourseName(paperScanTaskResult.getCourseName());
                    paperLibraryResult.setTeacherName(paperScanTaskResult.getTeacherName());
                    paperLibraryResult.setTeachClazzName(paperScanTaskResult.getTeachClazzName());
                }
                paperLibraryResult.setFileUrls(fileUrls);
                paperLibraryResultList.add(paperLibraryResult);
            }
        }
        return paperLibraryResultList;
    }

    @Override
    public IPage<TaskStudentResult> listByStudentCode(String studentCode, Integer pageNumber, Integer pageSize) {
        if (StringUtils.isBlank(studentCode)) {
            throw ExceptionResultEnum.ERROR.exception("请输入考号");
        }
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        return this.baseMapper.listByStudentCode(new Page<>(pageNumber, pageSize), schoolId, studentCode);
    }

    @Override
    public int countScanCount(Long paperScanTaskId) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        QueryWrapper<PaperLibrary> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(PaperLibrary::getSchoolId, schoolId)
                .eq(PaperLibrary::getPaperScanTaskId, paperScanTaskId);
        return this.count(queryWrapper);
    }

    @Override
    public IPage<TaskStudentResult> pageStudent(Long paperScanTaskId, String param, Boolean globalMatch, Integer pageNumber, Integer pageSize) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());

        // 全局匹配考生
        if (globalMatch) {
            return this.baseMapper.listByStudentCode(new Page<>(pageNumber, pageSize), schoolId, param);
        } else {
            IPage<TaskStudentResult> taskStudentResultIPage = this.baseMapper.pageStudent(new Page<>(pageNumber, pageSize), schoolId, paperScanTaskId, param);
            for (TaskStudentResult record : taskStudentResultIPage.getRecords()) {
                QueryWrapper<PaperLibrary> queryWrapper = new QueryWrapper<>();
                queryWrapper.lambda().eq(PaperLibrary::getPaperScanTaskDetailId, record.getPaperScanTaskDetailId());
                int count = paperLibraryService.count(queryWrapper);
                record.setBindCount(count);
            }
            return taskStudentResultIPage;
        }
    }

    @Override
    public List<String> ocr(Long paperLibraryId, Integer index, Integer x, Integer y, Integer width, Integer height, Integer rotate) {
        QueryWrapper<PaperLibrary> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(PaperLibrary::getId, paperLibraryId);
        PaperLibrary paperLibrary = this.getOne(queryWrapper);
        List<JSONObject> objectList = JSON.parseArray(paperLibrary.getPath(), JSONObject.class);
        JSONObject jsonObject = objectList.get(index);

        String rootPath = fileStoreUtil.buildPath(UploadFileEnum.DOWNLOAD, true);
        String cutRootPath = fileStoreUtil.buildPath(UploadFileEnum.CUT, true);
        File file;
        try {
            file = paperLibraryCommonService.downloadFile(rootPath, jsonObject.getString(SystemConstant.PATH), jsonObject.getString(SystemConstant.UPLOAD_TYPE), jsonObject.getString(SystemConstant.TYPE));
        } catch (FileNotFoundException e) {
            throw ExceptionResultEnum.ERROR.exception("下载图片失败：" + e.getMessage());
        }
        // 裁剪
        File outFile = new File(cutRootPath, "sub" + file.getName());
        if(!outFile.exists()){
            outFile.getParentFile().mkdirs();
        }
        File subFile = ImageUtil.subImg(file, x, y, width, height, outFile);
        if (subFile == null) {
            throw ExceptionResultEnum.ERROR.exception("识别区域图片生成失败");
        }

        // 旋转
        File rotateOutFile = new File(cutRootPath, "rotate" + file.getName());
        File rotateFile = ImageUtil.rotate(subFile, rotate, rotateOutFile);

        List<String> stringList = new ArrayList<>();
        try {
            org.json.JSONObject callHandwriting;
            if (rotateFile.exists()) {
                callHandwriting = ocrUtil.callHandwriting(rotateFile.getPath());
            } else {
                callHandwriting = ocrUtil.callHandwriting(subFile.getPath());
            }

            // 未联网提示
            if (!callHandwriting.has(SystemConstant.OCR_WORDS_RESULT)) {
                // ocr错误提示
                if (callHandwriting.has(SystemConstant.OCR_ERROR_MSG)) {
                    throw ExceptionResultEnum.ERROR.exception(callHandwriting.getString(SystemConstant.OCR_ERROR_MSG));
                } else {
                    throw ExceptionResultEnum.ERROR.exception("OCR识别异常，请检查网络是否连接或者关闭OCR识别");
                }
            }

            JSONArray jsonArray = callHandwriting.getJSONArray(SystemConstant.OCR_WORDS_RESULT);
            if (jsonArray.length() == 0) {
                throw ExceptionResultEnum.ERROR.exception("未正确识别出内容");
            } else {
                jsonArray.forEach(m -> {
                    org.json.JSONObject object = (org.json.JSONObject) m;
                    if (object.has(SystemConstant.OCR_WORDS)) {
                        stringList.add(object.getString(SystemConstant.OCR_WORDS));
                    }
                });

                // 保存识别数据
                UpdateWrapper<PaperLibrary> updateWrapper = new UpdateWrapper<>();
                updateWrapper.lambda().set(PaperLibrary::getWordsResult, jsonArray.toString())
                        .set(PaperLibrary::getOcrResult, String.join(",", stringList))
                        .eq(PaperLibrary::getId, paperLibraryId);
                this.update(updateWrapper);
            }
        } catch (JSONException e) {
            throw ExceptionResultEnum.ERROR.exception(e.getMessage());
        } finally {
            try {
                FileUtils.forceDelete(file);
//                FileUtils.forceDelete(subFile);
//                FileUtils.forceDelete(rotateFile);
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return stringList;
    }

    @Override
    public Boolean abnormal(Long paperLibraryId) {
        PaperLibrary paperLibrary = this.getById(paperLibraryId);
        if (paperLibrary == null) {
            throw ExceptionResultEnum.ERROR.exception("绑定对象有误，图片已删除，请刷新数据再试");
        }

        UpdateWrapper<PaperLibrary> updateWrapper = new UpdateWrapper<>();
        updateWrapper.lambda().set(PaperLibrary::getAbnormal, true).eq(PaperLibrary::getId, paperLibraryId);
        return this.update(updateWrapper);
    }

    private List<PaperLibrary> createBindData(Long userId, Long schoolId) {
        try {
            lockService.waitlock(LockType.BIND_PAPER_TASK, schoolId);
            List<PaperLibrary> paperLibraryList = this.baseMapper.listUnBindData(schoolId);
            if (!paperLibraryList.isEmpty()) {
                paperLibraryList.forEach(m -> m.setUserId(userId));
                this.updateBatchById(paperLibraryList);
            }
            return paperLibraryList;
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            lockService.unlock(LockType.BIND_PAPER_TASK, schoolId);
        }
        return new ArrayList<>();
    }

}
