package com.qmth.paper.library.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.paper.library.business.bean.dto.excel.ScannerBindingDto;
import com.qmth.paper.library.business.bean.params.PaperScanTaskParam;
import com.qmth.paper.library.business.bean.result.BindDetailResult;
import com.qmth.paper.library.business.bean.result.PaperScanTaskDetailResult;
import com.qmth.paper.library.business.bean.result.PaperScanTaskResult;
import com.qmth.paper.library.business.bean.result.SelectResult;
import com.qmth.paper.library.business.entity.PaperLibrary;
import com.qmth.paper.library.business.entity.PaperScanTask;
import com.qmth.paper.library.business.entity.PaperScanTaskDetail;
import com.qmth.paper.library.business.mapper.PaperScanTaskMapper;
import com.qmth.paper.library.business.service.PaperArchivesService;
import com.qmth.paper.library.business.service.PaperLibraryService;
import com.qmth.paper.library.business.service.PaperScanTaskDetailService;
import com.qmth.paper.library.business.service.PaperScanTaskService;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.entity.SysUser;
import com.qmth.paper.library.common.enums.ExceptionResultEnum;
import com.qmth.paper.library.common.service.SysUserService;
import com.qmth.paper.library.common.util.ExcelUtil;
import com.qmth.paper.library.common.util.ServletUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * <p>
 * 扫描任务表 服务实现类
 * </p>
 */
@Service
public class PaperScanTaskServiceImpl extends ServiceImpl<PaperScanTaskMapper, PaperScanTask> implements PaperScanTaskService {
    @Resource
    private PaperArchivesService paperArchivesService;
    @Resource
    private SysUserService sysUserService;
    @Resource
    private PaperLibraryService paperLibraryService;
    @Resource
    private PaperScanTaskDetailService paperScanTaskDetailService;

    @Override
    public IPage<PaperScanTaskResult> paperScanTaskPage(String courseName, String teacherName, Integer smallerProgress, Integer largerProgress, int pageNumber, int pageSize, SysUser requestUser) {
        Long schoolId = requestUser.getSchoolId();
        courseName = SystemConstant.strNotNull(courseName) ? SystemConstant.translateSpecificSign(courseName) : null;
        teacherName = SystemConstant.strNotNull(teacherName) ? SystemConstant.translateSpecificSign(teacherName) : null;
        return this.baseMapper.findPaperScanTaskPage(new Page<>(pageNumber, pageSize), schoolId, courseName, teacherName, smallerProgress, largerProgress, null);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Long editPaperScanTask(PaperScanTaskParam paperScanTaskParam, SysUser requestUser) {
        // 参数
        Long requestUserId = requestUser.getId();
        Long schoolId = requestUser.getSchoolId();
        Long paperScanTaskId = paperScanTaskParam.getPaperScanTaskId();
        Long paperArchivesId = paperScanTaskParam.getPaperArchivesId();
        if (Objects.isNull(paperArchivesService.getById(paperArchivesId))) {
            throw ExceptionResultEnum.ERROR.exception("未找到档案");
        }

        String scanTaskName = paperScanTaskParam.getScanTaskName();
        // 任务名称在档案下唯一
        PaperScanTask check = this.getOne(new QueryWrapper<PaperScanTask>()
                .lambda()
                .eq(PaperScanTask::getPaperArchivesId, paperArchivesId)
                .eq(PaperScanTask::getScanTaskName, scanTaskName));
        if (Objects.nonNull(check) && !Objects.equals(check.getId(), paperScanTaskId)) {
            throw ExceptionResultEnum.ERROR.exception("所选档案下已存在名称为【" + scanTaskName + "】的扫描任务");
        }

        String courseName = paperScanTaskParam.getCourseName();
        String teacherName = paperScanTaskParam.getTeacherName();
        String teacherClazzName = paperScanTaskParam.getTeachClazzName();
        Long scanUserId = paperScanTaskParam.getScanUserId();
        Integer studentCount = paperScanTaskParam.getStudentCount();
        if (SystemConstant.longNotNull(scanUserId)) {
            SysUser sysUser = sysUserService.getById(scanUserId);
            if (Objects.isNull(sysUser)) {
                throw ExceptionResultEnum.ERROR.exception("未找到扫描员");
            }
        }

        // 组装
        PaperScanTask paperScanTask = new PaperScanTask();
        paperScanTask.setSchoolId(schoolId);
        paperScanTask.setPaperArchivesId(paperArchivesId);
        paperScanTask.setScanTaskName(scanTaskName);
        paperScanTask.setCourseName(courseName);
        paperScanTask.setTeacherName(teacherName);
        paperScanTask.setTeachClazzName(teacherClazzName);
        paperScanTask.setStudentCount(studentCount);
        if (SystemConstant.longNotNull(scanUserId)) {
            paperScanTask.setScanUserId(scanUserId);
        }

        // 操作
        if (SystemConstant.longNotNull(paperScanTaskId)) {
            // 有扫描任务id - 编辑
            paperScanTask.updateInfo(requestUserId);
            paperScanTask.setId(paperScanTaskId);
        } else {
            // 没扫描任务id - 新增
            paperScanTask.insertInfo(requestUserId);
        }
        this.saveOrUpdate(paperScanTask);
        return paperScanTask.getId();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void deletePaperScanTaskByIdList(List<Long> idList, SysUser requestUser) {
        Long schoolId = requestUser.getSchoolId();
        if (idList != null && !idList.isEmpty()) {
            List<PaperLibrary> paperLibraryList = paperLibraryService.list(new QueryWrapper<PaperLibrary>()
                    .lambda()
                    .eq(PaperLibrary::getSchoolId, schoolId)
                    .in(PaperLibrary::getPaperScanTaskId, idList));

            if (!paperLibraryList.isEmpty()) {
                // 所选择要删除的扫描任务中出现了已经开始扫描的，不能被删除
                List<Long> cantDeleteScanTaskIdList = paperLibraryList.stream()
                        .map(PaperLibrary::getPaperScanTaskId)
                        .distinct()
                        .collect(Collectors.toList());

                if (!cantDeleteScanTaskIdList.isEmpty()) {
                    List<PaperScanTask> paperScanTaskList = this.list(new QueryWrapper<PaperScanTask>().lambda().in(PaperScanTask::getId, cantDeleteScanTaskIdList));
                    String cantDeleteScanTaskNames = paperScanTaskList.stream().map(PaperScanTask::getScanTaskName).collect(Collectors.joining(","));
                    throw ExceptionResultEnum.ERROR.exception("扫描任务【" + cantDeleteScanTaskNames + "】已扫描图片，不能删除");
                }
            } else {
                // 是否有图片绑定到该任务下
                QueryWrapper<PaperScanTaskDetail> queryWrapper = new QueryWrapper<>();
                queryWrapper.lambda().in(PaperScanTaskDetail::getPaperScanTaskId, idList);
                List<PaperScanTaskDetail> paperScanTaskDetail = paperScanTaskDetailService.list(queryWrapper);
                List<Long> paperTaskIdList = new ArrayList<>();
                if (!paperScanTaskDetail.isEmpty()) {
                    for (PaperScanTaskDetail paperScanTaskDetailTemp : paperScanTaskDetail) {
                        if (paperTaskIdList.contains(paperScanTaskDetailTemp.getId())) {
                            continue;
                        }
                        QueryWrapper<PaperLibrary> libraryQueryWrapper = new QueryWrapper<>();
                        libraryQueryWrapper.lambda().eq(PaperLibrary::getPaperScanTaskDetailId, paperScanTaskDetailTemp.getId());
                        int count = paperLibraryService.count(libraryQueryWrapper);
                        if (count > 0) {
                            paperTaskIdList.add(paperScanTaskDetailTemp.getPaperScanTaskId());
                        }
                    }
                }
                if (!paperTaskIdList.isEmpty()) {
                    List<PaperScanTask> paperScanTaskList = this.list(new QueryWrapper<PaperScanTask>().lambda().in(PaperScanTask::getId, paperTaskIdList));
                    String cantDeleteScanTaskNames = paperScanTaskList.stream().map(PaperScanTask::getScanTaskName).collect(Collectors.joining(","));
                    throw ExceptionResultEnum.ERROR.exception("扫描任务【" + cantDeleteScanTaskNames + "】已有图片绑定，不能删除");
                }
            }
        }
        this.removeByIds(idList);

        // 删除扫描详情
        paperScanTaskDetailService.remove(new QueryWrapper<PaperScanTaskDetail>().lambda().in(PaperScanTaskDetail::getPaperScanTaskId, idList));
    }

    @Override
    public void exportScanner(SysUser requestUser) throws Exception {
        Long schoolId = requestUser.getSchoolId();
        // 已经开始扫描的任务id
        List<Long> alreadyScannedTaskIdList = paperLibraryService.list(new QueryWrapper<PaperLibrary>().lambda()
                        .eq(PaperLibrary::getSchoolId, schoolId))
                .stream()
                .map(PaperLibrary::getPaperScanTaskId)
                .collect(Collectors.toList());

        QueryWrapper<PaperScanTask> paperScanTaskQueryWrapper = new QueryWrapper<>();
        paperScanTaskQueryWrapper.lambda().eq(PaperScanTask::getSchoolId, schoolId);
        if (alreadyScannedTaskIdList.size() > 0) {
            paperScanTaskQueryWrapper.lambda().notIn(PaperScanTask::getId, alreadyScannedTaskIdList);
        }
        List<PaperScanTask> paperScanTaskList = this.list(paperScanTaskQueryWrapper);
        List<ScannerBindingDto> scannerBindingDtoList = paperScanTaskList.stream().flatMap(e -> {
            String scanTaskName = e.getScanTaskName();
            String scannerName = "";
            Long scanUserId = e.getScanUserId();
            if (SystemConstant.longNotNull(scanUserId)) {
                SysUser scanner = sysUserService.getById(scanUserId);
                if (Objects.isNull(scanner)) {
                    throw ExceptionResultEnum.ERROR.exception("未找到扫描员");
                }
                scannerName = scanner.getRealName();
            }
            ScannerBindingDto scannerBindingDto = new ScannerBindingDto();
            scannerBindingDto.setScannerName(scannerName);
            scannerBindingDto.setScanTaskName(scanTaskName);
            return Stream.of(scannerBindingDto);
        }).collect(Collectors.toList());
        ExcelUtil.excelExport("绑定扫描员导入模板", ScannerBindingDto.class, scannerBindingDtoList, ServletUtil.getResponse());
    }

    @Override
    public IPage<PaperScanTaskDetailResult> findPaperScanTaskDetailPageByScanTaskId(Long paperScanTaskId, int pageNumber, int pageSize, SysUser requestUser) {
        Long schoolId = requestUser.getSchoolId();
        return this.baseMapper.findPaperScanTaskDetailPageByScanTaskId(new Page<>(pageNumber, pageSize), schoolId, paperScanTaskId);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void clearScanData(Long paperScanTaskId, SysUser requestUser) {
        Long schoolId = requestUser.getSchoolId();

        // 扫描任务校验
        PaperScanTask paperScanTask = this.getById(paperScanTaskId);
        if (Objects.isNull(paperScanTask)) {
            throw ExceptionResultEnum.ERROR.exception("扫描任务不存在");
        }
        // 要删除的图片数据集合
        List<PaperLibrary> willDeletePaperLibraryList = paperLibraryService.list(new QueryWrapper<PaperLibrary>()
                .lambda()
                .eq(PaperLibrary::getSchoolId, schoolId)
                .eq(PaperLibrary::getPaperScanTaskId, paperScanTaskId));

        if (willDeletePaperLibraryList.size() > 0) {
            // 已绑定的扫描任务校验
            List<PaperLibrary> cantDeleteList = willDeletePaperLibraryList
                    .stream()
                    .filter(e -> SystemConstant.longNotNull(e.getPaperScanTaskDetailId()))
                    .collect(Collectors.toList());

            if (cantDeleteList.size() > 0) {
                throw ExceptionResultEnum.ERROR.exception("所选的扫描任务已经进行了数据检验，不能删除");
            }

            // 删除该任务扫描的的数据
            paperLibraryService.removeByIds(willDeletePaperLibraryList.stream().map(PaperLibrary::getId).collect(Collectors.toList()));

            // 清除扫描量
            paperScanTask.setScanCount(null);
            paperScanTask.updateInfo(requestUser.getId());
            this.updateById(paperScanTask);
        }
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void unbindScanner(Long paperScanTaskId, SysUser requestUser) {
        PaperScanTask paperScanTask = this.getById(paperScanTaskId);
        if (Objects.isNull(paperScanTask)) {
            throw ExceptionResultEnum.ERROR.exception("扫描任务不存在");
        }
        paperScanTask.setScanUserId(null);
        paperScanTask.setEnable(false);
        paperScanTask.updateInfo(requestUser.getId());
        this.updateById(paperScanTask);
    }

    @Override
    public List<BindDetailResult> findBindDetailByScanTaskId(Long paperScanTaskId, SysUser requestUser) {
        Long schoolId = requestUser.getSchoolId();
        if (!SystemConstant.longNotNull(paperScanTaskId)) {
            throw ExceptionResultEnum.ERROR.exception("缺少扫描任务id");
        }
        return this.baseMapper.findBindDetailByScanTaskId(schoolId, paperScanTaskId);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public void releaseBindingTask(Long paperScanTaskId, Long bindUserId, SysUser requestUser) {
        UpdateWrapper<PaperLibrary> updateWrapper = new UpdateWrapper<>();
        updateWrapper.lambda()
                .set(PaperLibrary::getUserId, null)
                .set(PaperLibrary::getCreateId, requestUser.getId())
                .set(PaperLibrary::getCreateTime, System.currentTimeMillis())
                .eq(PaperLibrary::getPaperScanTaskId, paperScanTaskId)
                .eq(PaperLibrary::getUserId, bindUserId)
                .isNull(PaperLibrary::getPaperScanTaskDetailId);
        paperLibraryService.update(updateWrapper);
    }

    @Override
    public List<PaperScanTask> listByPaperArchivesId(Long paperArchivesId) {
        QueryWrapper<PaperScanTask> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(PaperScanTask::getPaperArchivesId, paperArchivesId);
        return this.list(queryWrapper);
    }

    @Override
    public List<SelectResult> queryCourse(Long paperArchivesId, Long semesterId) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        return this.baseMapper.queryCourse(schoolId, paperArchivesId, semesterId);
    }

    @Override
    public List<SelectResult> queryDataTeachClazz(Long paperArchivesId, String courseName) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        return this.baseMapper.queryDataTeachClazz(schoolId, paperArchivesId, courseName);
    }

    @Override
    public List<SelectResult> queryScanTask(Long paperArchivesId) {
        Long schoolId = Long.valueOf(ServletUtil.getRequestHeaderSchoolId().toString());
        QueryWrapper<PaperScanTask> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(PaperScanTask::getSchoolId, schoolId);
        if (paperArchivesId != null) {
            queryWrapper.lambda().eq(PaperScanTask::getPaperArchivesId, paperArchivesId);
        }
        List<PaperScanTask> paperScanTaskList = this.list(queryWrapper);
        return paperScanTaskList.stream().map(m -> {
            SelectResult result = new SelectResult();
            result.setId(String.valueOf(m.getId()));
            result.setName(m.getScanTaskName());
            return result;
        }).collect(Collectors.toList());
    }

    @Override
    public PaperScanTaskResult getByPaperScanTaskId(Long paperScanTaskId) {
        return this.baseMapper.getByPaperScanTaskId(paperScanTaskId);
    }

    @Override
    public boolean enable(Long paperScanTaskId, Boolean enable) {
        PaperScanTask paperScanTask = this.getById(paperScanTaskId);
        if (paperScanTask == null) {
            throw ExceptionResultEnum.ERROR.exception("任务数据异常");
        }
        paperScanTask.setEnable(enable);
        return this.updateById(paperScanTask);
    }
}
