package com.qmth.paper.library.business.templete.export;

import cn.hutool.core.date.DateUtil;
import com.alibaba.fastjson.JSONObject;
import com.qmth.boot.api.exception.ApiException;
import com.qmth.paper.library.business.templete.importData.AsyncImportTaskTemplate;
import com.qmth.paper.library.common.contant.SpringContextHolder;
import com.qmth.paper.library.common.contant.SysSettingConstant;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.entity.TBTask;
import com.qmth.paper.library.common.enums.TaskResultEnum;
import com.qmth.paper.library.common.enums.TaskStatusEnum;
import com.qmth.paper.library.common.enums.UploadFileEnum;
import com.qmth.paper.library.common.service.CommonCacheService;
import com.qmth.paper.library.common.service.TBTaskService;
import com.qmth.paper.library.common.util.FileStoreUtil;
import com.qmth.paper.library.common.util.Result;
import com.qmth.paper.library.common.util.ResultUtil;
import org.apache.commons.codec.digest.DigestUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.scheduling.annotation.Async;

import java.io.*;
import java.text.MessageFormat;
import java.util.Date;
import java.util.Map;
import java.util.Objects;
import java.util.StringJoiner;

/**
 * @Description: 异步导出模版
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2021/3/29
 */
public abstract class AsyncExportTaskTemplate {

    private final static Logger log = LoggerFactory.getLogger(AsyncImportTaskTemplate.class);
    public static final String BEGIN_TITLE = "->开始准备处理导出的";
    public static final String FINISH_TITLE = "->数据处理结束，共处理了";
    public static final String FINISH_SIZE = "条数据。";
    public static final String EXCEPTION_TITLE = "->数据处理发生异常!";
    public static final String EXCEPTION_DATA = "错误信息:";
    public static final String TXT_PREFIX = ".txt";
    public static final String EXCEPTION_CREATE_TXT_TITLE = "->创建导出日志时发生异常!";

    /**
     * 异步导出任务
     *
     * @param map
     * @return
     */
    @Async
    public abstract Result exportTask(Map<String, Object> map) throws Exception;

    /**
     * 创建txt文件
     *
     * @param tbTask
     */
    public void createTxt(TBTask tbTask) {
        FileStoreUtil fileStoreUtil = SpringContextHolder.getBean(FileStoreUtil.class);
        TBTaskService tbTaskService = SpringContextHolder.getBean(TBTaskService.class);
        ByteArrayOutputStream out = null;
        InputStream inputStream = null;
        try {
            String charset = SystemConstant.CHARSET_GBK;
            CommonCacheService commonCacheService = SpringContextHolder.getBean(CommonCacheService.class);
            if (commonCacheService != null) {
                String txtCharset = commonCacheService.getSysSettingGlobal().get(SysSettingConstant.SYS_TXT_CHARSET);
                if (StringUtils.isNotBlank(txtCharset)) {
                    charset = txtCharset;
                }
            }

            out = new ByteArrayOutputStream();
            out.write(tbTask.getSummary().getBytes(charset));
            byte[] bookByteAry = out.toByteArray();
            inputStream = new ByteArrayInputStream(bookByteAry);

            JSONObject jsonObject = JSONObject.parseObject(tbTask.getExportFilePath());
            if (Objects.isNull(jsonObject)) {
                jsonObject = new JSONObject();
                jsonObject.put(SystemConstant.TYPE, fileStoreUtil.getType());
                String rootPath = fileStoreUtil.buildPath(UploadFileEnum.FILE, true);
                String dirName = rootPath + File.separator + SystemConstant.getUuid() + TXT_PREFIX;
                jsonObject.put(SystemConstant.PATH, dirName);
            }
            String path = (String) jsonObject.get(SystemConstant.PATH);
            String type = (String) jsonObject.get(SystemConstant.TYPE);

            path = fileStoreUtil.replaceSlash(path);
            path = path.substring(0, path.lastIndexOf(SystemConstant.SINGLE_SLASH) + 1);

            StringJoiner stringJoiner = new StringJoiner("");
            stringJoiner.add(path).add(SystemConstant.getUuid()).add(TXT_PREFIX).toString();

            fileStoreUtil.fileUpload(stringJoiner.toString(), inputStream, DigestUtils.md5Hex(new ByteArrayInputStream(bookByteAry)));

            JSONObject json = new JSONObject();
            json.put(SystemConstant.PATH, stringJoiner.toString());
            json.put(SystemConstant.TYPE, type);
            json.put(SystemConstant.UPLOAD_TYPE, UploadFileEnum.FILE);
            tbTask.setTxtFilePath(json.toJSONString());
        } catch (Exception e) {
            log.error(SystemConstant.LOG_ERROR, e);
            StringJoiner stringJoinerSummary = new StringJoiner("").add(tbTask.getSummary()).add("\n");
            stringJoinerSummary.add(MessageFormat.format("{0}{1}{2}{3}", DateUtil.format(new Date(), SystemConstant.DEFAULT_DATE_PATTERN), EXCEPTION_CREATE_TXT_TITLE, EXCEPTION_DATA, e.getMessage()));
            tbTask.setSummary(stringJoinerSummary.toString());
            tbTask.setResult(TaskResultEnum.ERROR);
            if (e instanceof ApiException) {
                ResultUtil.error((ApiException) e, e.getMessage());
            } else {
                ResultUtil.error(e.getMessage());
            }
        } finally {
            try {
                if (Objects.nonNull(inputStream)) {
                    inputStream.close();
                }
                if (Objects.nonNull(out)) {
                    out.flush();
                    out.close();
                }
            } catch (IOException e) {
                log.error(SystemConstant.LOG_ERROR, e);
            }
            tbTask.setStatus(TaskStatusEnum.FINISH);
            tbTaskService.updateById(tbTask);
        }
    }
}
