package com.qmth.paper.library.business.templete.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.google.common.collect.Lists;
import com.qmth.boot.api.exception.ApiException;
import com.qmth.paper.library.business.bean.dto.excel.PaperScanTaskImportDto;
import com.qmth.paper.library.business.bean.params.PaperScanTaskParam;
import com.qmth.paper.library.business.bean.result.PaperArchivesDetailResult;
import com.qmth.paper.library.business.entity.PaperArchives;
import com.qmth.paper.library.business.entity.PaperLibrary;
import com.qmth.paper.library.business.entity.PaperScanTask;
import com.qmth.paper.library.business.entity.PaperScanTaskDetail;
import com.qmth.paper.library.business.service.*;
import com.qmth.paper.library.business.templete.service.TaskLogicService;
import com.qmth.paper.library.common.bean.dto.excel.BasicStudentImportDto;
import com.qmth.paper.library.common.bean.dto.excel.DescribeImportDto;
import com.qmth.paper.library.common.bean.dto.excel.SysOrgImportDto;
import com.qmth.paper.library.common.bean.dto.excel.SysUserImportDto;
import com.qmth.paper.library.common.bean.params.DownLoadPaperParams;
import com.qmth.paper.library.common.config.DictionaryConfig;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.entity.BasicStudent;
import com.qmth.paper.library.common.entity.SysUser;
import com.qmth.paper.library.common.entity.TBTask;
import com.qmth.paper.library.common.enums.ExceptionResultEnum;
import com.qmth.paper.library.common.enums.UploadFileEnum;
import com.qmth.paper.library.common.service.BasicStudentService;
import com.qmth.paper.library.common.service.SysOrgService;
import com.qmth.paper.library.common.service.SysUserService;
import com.qmth.paper.library.common.util.*;
import com.qmth.paper.library.common.util.excel.ExcelError;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.ss.usermodel.*;
import org.apache.poi.xssf.usermodel.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;
import org.springframework.util.LinkedMultiValueMap;

import javax.annotation.Resource;
import java.io.*;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @Description: 任务处理逻辑impl
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2021/3/29
 */
@Service
public class TaskLogicServiceImpl implements TaskLogicService {
    private final static Logger log = LoggerFactory.getLogger(TaskLogicServiceImpl.class);

    @Resource
    private DictionaryConfig dictionaryConfig;
    @Resource
    private SysOrgService sysOrgService;

    @Resource
    SysUserService sysUserService;
    @Resource
    private PaperArchivesService paperArchivesService;
    @Resource
    private PaperScanTaskService paperScanTaskService;
    @Resource
    private PaperScanTaskDetailService paperScanTaskDetailService;
    @Resource
    private BasicStudentService basicStudentService;
    @Resource
    PaperLibraryCommonService paperLibraryCommonService;
    @Resource
    private FileStoreUtil fileStoreUtil;
    @Resource
    PaperLibraryService paperLibraryService;

    @Transactional
    @Override
    public Map<String, Object> executeImportSysOrgLogic(Map<String, Object> map) throws IOException, NoSuchFieldException {
        InputStream inputStream = (InputStream) map.get("inputStream");
        List<LinkedMultiValueMap<Integer, Object>> finalList = ExcelUtil.excelReader(inputStream, Lists.newArrayList(SysOrgImportDto.class, DescribeImportDto.class), (finalExcelList, finalColumnNameList, finalExcelErrorList) -> finalExcelList);
        List<String> orgInfoList = new ArrayList<>();
        for (int i = 0; i < finalList.size(); i++) {
            LinkedMultiValueMap<Integer, Object> excelMap = finalList.get(i);
            List<Object> sysOrgImportDtoList = excelMap.get(i);
            assert sysOrgImportDtoList != null;
            if (sysOrgImportDtoList.get(0) instanceof DescribeImportDto) {
                continue;
            }
            map.put("dataCount", sysOrgImportDtoList.size());
            //  处理机构
            if (sysOrgImportDtoList.get(0) instanceof SysOrgImportDto) {
                List<SysOrgImportDto> datasource = sysOrgImportDtoList.stream().map(e -> {
                    SysOrgImportDto sysOrgImportDto = new SysOrgImportDto();
                    BeanUtils.copyProperties(e, sysOrgImportDto);
                    return sysOrgImportDto;
                }).collect(Collectors.toList());
                if (datasource.size() > 0) {
                    datasource.forEach(e -> orgInfoList.add(e.getName()));
                }
            }
        }
        if (orgInfoList.size() > 0) {
            SysUser requestUser = (SysUser) map.get(SystemConstant.SYS_USER);
            sysOrgService.createOrGetOrgByOrgInfo(orgInfoList, requestUser);
        }
        return map;
    }

    @Transactional
    @Override
    public Map<String, Object> executeImportSysUserLogic(Map<String, Object> map) throws Exception {
        InputStream inputStream = (InputStream) map.get("inputStream");
        List<LinkedMultiValueMap<Integer, Object>> finalList = ExcelUtil.excelReader(inputStream, Lists.newArrayList(SysUserImportDto.class, DescribeImportDto.class), (finalExcelList, finalColumnNameList, finalExcelErrorList) -> {
            List<ExcelError> excelErrorTemp = new ArrayList<>();
            Map<String, SysUserImportDto> checkDtoMap = new HashMap<>();

            for (int i = 0; i < finalExcelList.size(); i++) {
                LinkedMultiValueMap<Integer, Object> excelMap = finalExcelList.get(i);
                List<Object> sysUserImportDtoList = excelMap.get(i);
                assert sysUserImportDtoList != null;
                if (sysUserImportDtoList.get(0) instanceof DescribeImportDto) {
                    continue;
                }
                map.put("dataCount", sysUserImportDtoList.size());
                List<SysUserImportDto> duplicateData = new ArrayList<>();
                for (int y = 0; y < Objects.requireNonNull(sysUserImportDtoList).size(); y++) {
                    SysUserImportDto sysUserImportDto = (SysUserImportDto) sysUserImportDtoList.get(y);
                    String name = StringUtils.isNotBlank(sysUserImportDto.getName()) ? sysUserImportDto.getName().trim() : null;
                    String loginName = StringUtils.isNotBlank(sysUserImportDto.getLoginName()) ? sysUserImportDto.getLoginName().trim() : null;
//                    String phoneNumber = StringUtils.isNotBlank(sysUserImportDto.getPhoneNumber()) ? sysUserImportDto.getPhoneNumber().trim() : null;
                    String orgName = StringUtils.isNotBlank(sysUserImportDto.getOrgName()) ? sysUserImportDto.getOrgName().trim() : null;
                    String roleName = StringUtils.isNotBlank(sysUserImportDto.getRoleName()) ? sysUserImportDto.getRoleName().trim() : null;

                    if (checkDtoMap.containsKey(loginName)) {
                        SysUserImportDto primaryCell = checkDtoMap.get(loginName);
                        String priName = primaryCell.getName();
//                        String priPhoneNumber = primaryCell.getPhoneNumber();
                        String priOrgName = primaryCell.getOrgName();
                        if (!Objects.equals(priName, name)) {
                            throw ExceptionResultEnum.ERROR.exception("【用户名】 ：" + loginName + "的用户存在不同的名称");
                        }
//                        if (!Objects.equals(priPhoneNumber, phoneNumber)) {
//                            throw ExceptionResultEnum.ERROR.exception("【账号】 ：" + loginName + "的用户存在不同的手机号");
//                        }
                        if (!Objects.equals(priOrgName, orgName)) {
                            throw ExceptionResultEnum.ERROR.exception("【用户名】 ：" + loginName + "的用户存在不同的组织架构");
                        }
                        String priRoleName = primaryCell.getRoleName();
                        if (SystemConstant.strNotNull(roleName)) {
                            priRoleName = priRoleName + SystemConstant.COMMA + roleName;
                            primaryCell.setRoleName(priRoleName);
                        }
                        duplicateData.add(sysUserImportDto);
                    } else {
                        checkDtoMap.put(loginName, sysUserImportDto);
                    }

                    excelErrorTemp.addAll(ExcelUtil.checkExcelField(sysUserImportDto, y, i));
                    if (Objects.isNull(loginName) || loginName.length() > 30 || !loginName.matches(SystemConstant.REGULAR_EXPRESSION_OF_CODE)) {
                        excelErrorTemp.add(new ExcelError(y + 1, "excel第" + (i + 1) + "个sheet第" + (y + 1) + "行[账号]不符合输入规范"));
                    }
                    if (Objects.isNull(name) || name.length() > 30) {
                        excelErrorTemp.add(new ExcelError(y + 1, "excel第" + (i + 1) + "个sheet第" + (y + 1) + "行[姓名]不符合输入规范"));
                    }
//                    if (Objects.nonNull(phoneNumber) && !phoneNumber.matches(SystemConstant.REGULAR_EXPRESSION_OF_PHONE)) {
//                        excelErrorTemp.add(new ExcelError(y + 1, "excel第" + (i + 1) + "个sheet第" + (y + 1) + "行[电话号码]不符合输入规范"));
//                    }
                }
                sysUserImportDtoList.removeAll(duplicateData);
            }
            if (excelErrorTemp.size() > 0) {
                throw ExceptionResultEnum.ERROR.exception(JSONObject.toJSONString(excelErrorTemp));
            }
            return finalExcelList;
        });
        return sysUserService.executeSysUserImportLogic(finalList, map);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Map<String, Object> executeImportPaperScanTaskDetailLogic(Map<String, Object> map) throws Exception {
        SysUser requestUser = (SysUser) map.get(SystemConstant.SYS_USER);
        Long schoolId = requestUser.getSchoolId();
        InputStream inputStream = (InputStream) map.get("inputStream");

        List<LinkedMultiValueMap<Integer, Object>> finalList = ExcelUtil.excelReader(inputStream, Lists.newArrayList(PaperScanTaskImportDto.class, DescribeImportDto.class), (finalExcelList, finalColumnNameList, finalExcelErrorList) -> finalExcelList);
        List<PaperScanTaskImportDto> datasource = new ArrayList<>();
        for (int i = 0; i < finalList.size(); i++) {
            LinkedMultiValueMap<Integer, Object> excelMap = finalList.get(i);
            List<Object> paperScanTaskImportDtoList = excelMap.get(i);
            assert paperScanTaskImportDtoList != null;
            if (paperScanTaskImportDtoList.get(0) instanceof DescribeImportDto) {
                continue;
            }
            map.put("dataCount", paperScanTaskImportDtoList.size());
            //  处理机构
            if (paperScanTaskImportDtoList.get(0) instanceof PaperScanTaskImportDto) {
                datasource = paperScanTaskImportDtoList.stream().map(e -> {
                    PaperScanTaskImportDto paperScanTaskImportDto = new PaperScanTaskImportDto();
                    BeanUtils.copyProperties(e, paperScanTaskImportDto);
                    return paperScanTaskImportDto;
                }).collect(Collectors.toList());
            }
        }
        if (datasource.size() > 0) {
            // 选择的扫描档案id
            Long paperArchivesId = SystemConstant.convertIdToLong(String.valueOf(map.get("paperArchivesId")));
            List<Map<String, String>> archivesCheckMapList = datasource.stream().flatMap(e -> {
                Map<String, String> checkMap = new HashMap<>();
                checkMap.put("archivesName", e.getArchivesName());
                checkMap.put("archivesCode", e.getArchivesCode());
                return Stream.of(checkMap);
            }).distinct().collect(Collectors.toList());

            if (archivesCheckMapList.size() != 1) {
                throw ExceptionResultEnum.ERROR.exception("excel中的档案信息异常（导入扫描任务数据必须是一个档案下的）");
            }
            Map<String, String> archivesCheckMap = archivesCheckMapList.get(0);
            String archivesName = archivesCheckMap.get("archivesName");
            String archivesCode = archivesCheckMap.get("archivesCode");

            // 判断选择的档案和导入的是同一个
            PaperArchives paperArchives = paperArchivesService.getOne(new QueryWrapper<PaperArchives>()
                    .lambda()
                    .eq(PaperArchives::getId, paperArchivesId)
                    .eq(PaperArchives::getArchivesCode, archivesCode)
                    .eq(PaperArchives::getArchivesName, archivesName));
            if (Objects.isNull(paperArchives)) {
                throw ExceptionResultEnum.ERROR.exception("excel中的档案信息和选择的档案不符");
            }

            // 归纳 - 扫描任务集合
            // 扫描任务唯一信息
            Map<String, PaperScanTask> paperScanTaskMap = new HashMap<>();
            for (PaperScanTaskImportDto paperScanTaskImportDto : datasource) {
                String scanTaskName = paperScanTaskImportDto.getScanTaskName();
                String courseName = paperScanTaskImportDto.getCourseName();
                String teacherName = paperScanTaskImportDto.getTeacherName();
                String teachClazzName = paperScanTaskImportDto.getTeachClazzName();

                if (paperScanTaskMap.containsKey(scanTaskName)) {
                    // 如果试卷任务map中包含该任务名称 - 检验其他信息是否一致(课程，任课教师，教学班 为空的不检验)
                    PaperScanTask v = paperScanTaskMap.get(scanTaskName);
                    String vCourseName = v.getCourseName();
                    String vTeacherName = v.getTeacherName();
                    String vTeachClazzName = v.getTeachClazzName();

                    // 同一任务课程名称检验
                    if (!SystemConstant.strNotNull(vCourseName)) {
                        v.setCourseName(courseName);
                    } else if (SystemConstant.strNotNull(courseName) && !vCourseName.equals(courseName)) {
                        throw ExceptionResultEnum.ERROR.exception("excel数据异常：导入的任务【" + scanTaskName + "】存在不同的课程名称【" + vCourseName + "," + courseName + "】");
                    }

                    // 同一任务任课教师检验
                    if (!SystemConstant.strNotNull(vTeacherName)) {
                        v.setTeacherName(teacherName);
                    } else if (SystemConstant.strNotNull(teacherName) && !vTeacherName.equals(teacherName)) {
                        throw ExceptionResultEnum.ERROR.exception("excel数据异常：导入的任务【" + scanTaskName + "】存在不同的任课教师【" + vTeacherName + "," + teacherName + "】");
                    }

                    // 同一任务教学班检验
                    if (!SystemConstant.strNotNull(vTeachClazzName)) {
                        v.setTeachClazzName(teachClazzName);
                    } else if (SystemConstant.strNotNull(teachClazzName) && !vTeachClazzName.equals(teachClazzName)) {
                        throw ExceptionResultEnum.ERROR.exception("excel数据异常：导入的任务【" + scanTaskName + "】存在不同的教学班【" + vTeachClazzName + "," + teachClazzName + "】");
                    }
                } else {
                    // 没包含直接put
                    PaperScanTask v = new PaperScanTask();
                    v.setScanTaskName(scanTaskName);
                    v.setCourseName(courseName);
                    v.setTeacherName(teacherName);
                    v.setTeachClazzName(teachClazzName);
                    paperScanTaskMap.put(scanTaskName, v);
                }
            }

            // 创建扫描任务并把编辑后的任务id放回map中
            List<Long> paperScanTaskIdList = new ArrayList<>();
            for (String k : paperScanTaskMap.keySet()) {
                PaperScanTask v = paperScanTaskMap.get(k);
                PaperScanTask db = paperScanTaskService.getOne(new QueryWrapper<PaperScanTask>()
                        .lambda()
                        .eq(PaperScanTask::getSchoolId, requestUser.getSchoolId())
                        .eq(PaperScanTask::getScanTaskName, k)
                        .eq(PaperScanTask::getPaperArchivesId, paperArchivesId));
                PaperScanTaskParam paperScanTaskParam = new PaperScanTaskParam();
                if (Objects.nonNull(db)) {
                    // 编辑
                    paperScanTaskParam.setPaperScanTaskId(db.getId());
                    paperScanTaskIdList.add(db.getId());
                }
                paperScanTaskParam.setPaperArchivesId(paperArchivesId);
                paperScanTaskParam.setCourseName(v.getCourseName());
                paperScanTaskParam.setTeacherName(v.getTeacherName());
                paperScanTaskParam.setTeachClazzName(v.getTeachClazzName());
                paperScanTaskParam.setScanTaskName(k);
                Long paperScanTaskId = paperScanTaskService.editPaperScanTask(paperScanTaskParam, requestUser);
                v.setId(paperScanTaskId);
            }

            // 归纳 - 扫描任务详情
            // 上面编辑的任务绑定的扫描详情集合
            List<PaperScanTaskDetail> paperScanTaskDetailDbList = new ArrayList<>();
            if (paperScanTaskIdList.size() > 0) {
                paperScanTaskDetailDbList = paperScanTaskDetailService.list(new QueryWrapper<PaperScanTaskDetail>()
                        .lambda()
                        .in(PaperScanTaskDetail::getPaperScanTaskId, paperScanTaskIdList)
                        .eq(PaperScanTaskDetail::getSchoolId, schoolId));
            }
            List<PaperScanTaskDetail> finalPaperScanTaskDetailDbList = paperScanTaskDetailDbList;

            // 学生基础数据集合
            List<BasicStudent> basicStudentDbList = basicStudentService.list(new QueryWrapper<BasicStudent>().lambda().eq(BasicStudent::getSchoolId, schoolId));
            List<PaperScanTaskDetail> paperScanTaskDetailList = datasource.stream().flatMap(e -> {

                String scanTaskName = e.getScanTaskName();
                PaperScanTask paperScanTask = paperScanTaskMap.get(scanTaskName);
                if (Objects.isNull(paperScanTask)) {
                    throw ExceptionResultEnum.ERROR.exception("扫描任务数据异常");
                }
                Long paperScanTaskId = paperScanTask.getId();

                String studentCode = e.getStudentCode();
                List<BasicStudent> studentList = basicStudentDbList.stream().filter(s -> s.getStudentCode().equals(studentCode)).collect(Collectors.toList());
                if (studentList.size() != 1) {
                    throw ExceptionResultEnum.ERROR.exception("学号为【" + studentCode + "】的学生不存在或异常");
                }
                // 目标学生
                BasicStudent targetStudent = studentList.get(0);
                if (!e.getStudentName().equals(targetStudent.getStudentName())) {
                    throw ExceptionResultEnum.ERROR.exception("学号为【" + studentCode + "】的学生姓名与基础信息中姓名不一致");
                }

                Long studentId = targetStudent.getId();

                PaperScanTaskDetail paperScanTaskDetail = new PaperScanTaskDetail();
                List<PaperScanTaskDetail> paperScanTaskDetailCellList = finalPaperScanTaskDetailDbList.stream()
                        .filter(d -> d.getPaperScanTaskId().equals(paperScanTaskId) && d.getStudentId().equals(studentId) && d.getSchoolId().equals(schoolId))
                        .collect(Collectors.toList());
                if (paperScanTaskDetailCellList.size() == 1) {
                    paperScanTaskDetail.setId(paperScanTaskDetailCellList.get(0).getId());
                }
                paperScanTaskDetail.setPaperScanTaskId(paperScanTaskId);
                paperScanTaskDetail.setSchoolId(schoolId);
                paperScanTaskDetail.setStudentId(studentId);
                return Stream.of(paperScanTaskDetail);
            }).collect(Collectors.toList());
            paperScanTaskDetailService.saveOrUpdateBatch(paperScanTaskDetailList);

            // 更新扫描任务冗余字段扫描份数（学生数量）
            List<PaperScanTask> paperScanTaskList = paperScanTaskService.list(new QueryWrapper<PaperScanTask>()
                    .lambda()
                    .eq(PaperScanTask::getSchoolId, schoolId)
                    .eq(PaperScanTask::getPaperArchivesId, paperArchivesId));
            for (PaperScanTask paperScanTask : paperScanTaskList) {
                Long paperScanTaskId = paperScanTask.getId();
                int studentCount = paperScanTaskDetailService.count(new QueryWrapper<PaperScanTaskDetail>()
                        .lambda()
                        .eq(PaperScanTaskDetail::getPaperScanTaskId, paperScanTaskId));
                paperScanTask.setStudentCount(studentCount);
                paperScanTask.setEnable(false);
            }
            paperScanTaskService.saveOrUpdateBatch(paperScanTaskList);
        }
        return map;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Map<String, Object> executeImportBasicStudentLogic(Map<String, Object> map) throws Exception {
        InputStream inputStream = (InputStream) map.get("inputStream");
        System.out.println(inputStream);
        List<String> studentCodeList = new ArrayList<>();
        List<LinkedMultiValueMap<Integer, Object>> finalList = ExcelUtil.excelReader(inputStream, Lists.newArrayList(BasicStudentImportDto.class, DescribeImportDto.class), (finalExcelList, finalColumnNameList, finalExcelErrorList) -> {
            List<ExcelError> excelErrorTemp = new ArrayList<>();
            Map<String, String> checkCodeMap = new HashMap<>();
            Map<String, String> checkPhoneMap = new HashMap<>();
            for (int i = 0; i < finalExcelList.size(); i++) {
                LinkedMultiValueMap<Integer, Object> excelMap = finalExcelList.get(i);
                List<Object> basicStudentImportDtoList = excelMap.get(i);
                assert basicStudentImportDtoList != null;
                if (basicStudentImportDtoList.get(0) instanceof DescribeImportDto) {
                    continue;
                }
                for (int y = 0; y < Objects.requireNonNull(basicStudentImportDtoList).size(); y++) {
                    BasicStudentImportDto basicStudentImportDto = (BasicStudentImportDto) basicStudentImportDtoList.get(y);
                    String studentName = basicStudentImportDto.getStudentName();
                    String studentCode = basicStudentImportDto.getStudentCode();
                    String phoneNumber = basicStudentImportDto.getPhoneNumber();
                    String clazzName = basicStudentImportDto.getClazzName();
                    studentCodeList.add(studentCode);

                    // 检验excel中
                    // 检验学号
                    if (SystemConstant.strNotNull(studentCode)) {
                        if (checkCodeMap.containsKey(studentCode)) {
                            throw ExceptionResultEnum.ERROR.exception("导入的excel中包含在重复的【学生编号】：" + studentCode);
                        } else {
                            checkCodeMap.put(studentCode, studentName);
                        }
                    }
                    // 如果电话有值则检验电话excel中唯一性
                    if (SystemConstant.strNotNull(phoneNumber)) {
                        if (checkPhoneMap.containsKey(phoneNumber)) {
                            throw ExceptionResultEnum.ERROR.exception("导入的excel中包含在重复的【电话号码】：" + phoneNumber);
                        } else {
                            checkPhoneMap.put(phoneNumber, studentCode);
                        }
                    }

                    excelErrorTemp.addAll(ExcelUtil.checkExcelField(basicStudentImportDto, y, i));
                    if (Objects.isNull(studentCode) || studentCode.length() > 30 || !studentCode.matches(SystemConstant.REGULAR_EXPRESSION_OF_CODE)) {
                        excelErrorTemp.add(new ExcelError(y + 1, "excel第" + (i + 1) + "个sheet第" + (y + 1) + "行[学号]不符合输入规范"));
                    }
                    if (Objects.isNull(studentName) || studentName.length() > 30) {
                        excelErrorTemp.add(new ExcelError(y + 1, "excel第" + (i + 1) + "个sheet第" + (y + 1) + "行[学生名称]不符合输入规范"));
                    }
                    if (Objects.nonNull(phoneNumber) && !phoneNumber.matches(SystemConstant.REGULAR_EXPRESSION_OF_PHONE)) {
                        excelErrorTemp.add(new ExcelError(y + 1, "excel第" + (i + 1) + "个sheet第" + (y + 1) + "行[电话号码]不符合输入规范"));
                    }
                }
            }
            if (excelErrorTemp.size() > 0) {
                throw ExceptionResultEnum.ERROR.exception(JSONObject.toJSONString(excelErrorTemp));
            }
            map.put("studentCodeList", studentCodeList);
            return finalExcelList;
        });
        return basicStudentService.executeBasicStudentImportLogic(finalList, map);
    }

    @Override
    public Map<String, Object> executeDownloadPaperLogic(Map<String, Object> map) {
        List<File> sourceFileList = new ArrayList<>();
        File zipFile = null;
        String zipLocalRootPath = null;
        try {
            TBTask tbTask = (TBTask) map.get(SystemConstant.TASK);
            DownLoadPaperParams downLoadPaperParams = JSON.parseObject(tbTask.getRemark(), DownLoadPaperParams.class);

            List<PaperArchivesDetailResult> archivesDetailResults = paperArchivesService.listDetail(downLoadPaperParams);
            String rootPath = fileStoreUtil.buildPath(UploadFileEnum.DOWNLOAD, true);
            String dirName = SystemConstant.getUuid() + SystemConstant.ZIP_PREFIX;
            zipFile = new File(rootPath + dirName);
            if (!zipFile.getParentFile().exists()) {
                zipFile.getParentFile().mkdirs();
            }
            zipLocalRootPath = dictionaryConfig.fssDomain().getConfig() + File.separator + UploadFileEnum.DOWNLOAD.getPrefix() + File.separator + SystemConstant.getUuid();
            Map<String, Integer> successMap = new HashMap<>();
            Map<String, Integer> errorMap = new HashMap<>();
            for (PaperArchivesDetailResult archivesDetailResult : archivesDetailResults) {
                String paperScanTaskDetailId = archivesDetailResult.getPaperScanTaskDetailId();
                successMap.putIfAbsent(paperScanTaskDetailId, 0);
                errorMap.putIfAbsent(paperScanTaskDetailId, 0);
                QueryWrapper<PaperLibrary> queryWrapper = new QueryWrapper<>();
                queryWrapper.lambda().eq(PaperLibrary::getPaperScanTaskDetailId, archivesDetailResult.getPaperScanTaskDetailId());
                List<PaperLibrary> paperLibraryList = paperLibraryService.list(queryWrapper);
                for (PaperLibrary paperLibrary : paperLibraryList) {
                    List<JSONObject> objectList = JSON.parseArray(paperLibrary.getPath(), JSONObject.class);
                    for (JSONObject jsonObject : objectList) {
                        try {
                            String imagePath = zipLocalRootPath + File.separator + archivesDetailResult.getCourseName() + File.separator + archivesDetailResult.getTeachClazzName() + File.separator + archivesDetailResult.getStudentCode();
                            File file = paperLibraryCommonService.downloadFile(imagePath, jsonObject.getString(SystemConstant.PATH), jsonObject.getString(SystemConstant.UPLOAD_TYPE), jsonObject.getString(SystemConstant.TYPE));
                            sourceFileList.add(file);
                            successMap.put(paperScanTaskDetailId, successMap.get(paperScanTaskDetailId) + 1);
                        } catch (FileNotFoundException e) {
                            errorMap.put(paperScanTaskDetailId, successMap.get(paperScanTaskDetailId) + 1);
                        }
                    }
                }
            }

            if (!CollectionUtils.isEmpty(sourceFileList)) {
                // 生成清单
                createPaperDownloadExcel(zipLocalRootPath, archivesDetailResults, successMap, errorMap);

                Zip4jUtil.zipEncryptFile(zipFile.getPath(), zipLocalRootPath, SystemConstant.ZIP_ENCRYPT_PWD);
                String ossDirName = dirName.replaceAll("\\\\", "/");
                JSONObject jsonObject = new JSONObject();
                if (fileStoreUtil.isOssStore()) {
                    fileStoreUtil.fileUpload(ossDirName, zipFile);
                    jsonObject.put(SystemConstant.PATH, ossDirName);
                    jsonObject.put(SystemConstant.TYPE, SystemConstant.OSS);
                } else {
                    jsonObject.put(SystemConstant.TYPE, SystemConstant.LOCAL);
                    jsonObject.put(SystemConstant.PATH, rootPath + ossDirName);
                }
                jsonObject.put(SystemConstant.UPLOAD_TYPE, UploadFileEnum.FILE);
                tbTask.setExportFilePath(jsonObject.toJSONString());
            }
            map.put(SystemConstant.SIZE, Objects.nonNull(archivesDetailResults) ? archivesDetailResults.size() : 0);
        } catch (
                Exception e) {
            log.error(SystemConstant.LOG_ERROR, e);
            if (e instanceof ApiException) {
                ResultUtil.error((ApiException) e, e.getMessage());
            } else {
                ResultUtil.error(e.getMessage());
            }
        } finally {
            if (Objects.nonNull(zipLocalRootPath)) {
                ConvertUtil.delFolder(zipLocalRootPath);
            }
            if (Objects.nonNull(dictionaryConfig.sysDomain()) && fileStoreUtil.isOssStore() && Objects.nonNull(zipFile)) {
                zipFile.delete();
            }
        }
        return map;
    }

    /**
     * 生成清单
     *
     * @param zipLocalRootPath 路径
     * @param list             数据
     * @param successMap
     * @param errorMap
     */
    public void createPaperDownloadExcel(String zipLocalRootPath, List<PaperArchivesDetailResult> list, Map<String, Integer> successMap, Map<String, Integer> errorMap) throws IOException {
        String fileName = "下载清单.xlsx";
        XSSFWorkbook wb = new XSSFWorkbook();
        XSSFSheet sheet = wb.createSheet("数据");

        // 表头
        CellStyle headerStyle = wb.createCellStyle();
        headerStyle.setAlignment(HorizontalAlignment.CENTER);
        headerStyle.setVerticalAlignment(VerticalAlignment.CENTER);
        headerStyle.setBorderRight(BorderStyle.THIN);
        headerStyle.setRightBorderColor(IndexedColors.BLACK.getIndex());
        headerStyle.setBorderLeft(BorderStyle.THIN);
        headerStyle.setLeftBorderColor(IndexedColors.BLACK.getIndex());
        headerStyle.setBorderTop(BorderStyle.THIN);
        headerStyle.setTopBorderColor(IndexedColors.BLACK.getIndex());
        headerStyle.setBorderBottom(BorderStyle.THIN);
        headerStyle.setBottomBorderColor(IndexedColors.BLACK.getIndex());
        // 背景颜色
        headerStyle.setFillPattern(FillPatternType.SOLID_FOREGROUND);
        headerStyle.setFillForegroundColor(IndexedColors.GREY_80_PERCENT.getIndex());
        Font font = wb.createFont();
        font.setFontHeightInPoints((short) 12);
        font.setFontName("宋体");
        font.setColor(IndexedColors.WHITE.getIndex());
        headerStyle.setFont(font);

        // 数据
        XSSFCellStyle dataStyle = wb.createCellStyle();
        dataStyle.setAlignment(HorizontalAlignment.CENTER);
        dataStyle.setVerticalAlignment(VerticalAlignment.CENTER);
        dataStyle.setBorderRight(BorderStyle.THIN);
        dataStyle.setRightBorderColor(IndexedColors.BLACK.getIndex());
        dataStyle.setBorderLeft(BorderStyle.THIN);
        dataStyle.setLeftBorderColor(IndexedColors.BLACK.getIndex());
        dataStyle.setBorderTop(BorderStyle.THIN);
        dataStyle.setTopBorderColor(IndexedColors.BLACK.getIndex());
        dataStyle.setBorderBottom(BorderStyle.THIN);
        dataStyle.setBottomBorderColor(IndexedColors.BLACK.getIndex());
        dataStyle.setFillPattern(FillPatternType.SOLID_FOREGROUND);
        // 背景颜色
        dataStyle.setFillForegroundColor(IndexedColors.GREY_25_PERCENT.getIndex());
        font = wb.createFont();
        font.setFontHeightInPoints((short) 10);
        font.setFontName("宋体");
        dataStyle.setFont(font);

        // 锁定样式
        XSSFCellStyle lockStyle = wb.createCellStyle();
        lockStyle.setLocked(true);//设置锁定

        // 未锁定样式
        XSSFCellStyle unlockStyle = wb.createCellStyle();
        unlockStyle.setLocked(false);//设置未锁定

        XSSFRow headRow = sheet.createRow(0);
        // 表头
        String[] fieldsNameList = {"学生姓名", "学号", "专业", "班级", "课程", "任课老师", "教学班", "绑定图片数量（张）", "下载成功数量（页）", "下载失败（页）"};
        for (int i = 0; i < fieldsNameList.length; i++) {
            XSSFCell cell = headRow.createCell(i);
            cell.setCellValue(fieldsNameList[i]);
            cell.setCellStyle(headerStyle);
        }

        for (int i = 1; i <= list.size(); i++) {
            PaperArchivesDetailResult paperArchivesDetailResult = list.get(i - 1);
            XSSFRow row = sheet.createRow(i);

            XSSFCell cell0 = row.createCell(0);
            cell0.setCellStyle(lockStyle);
            cell0.setCellStyle(dataStyle);
            cell0.setCellValue(paperArchivesDetailResult.getStudentName());

            XSSFCell cell1 = row.createCell(1);
            cell1.setCellStyle(lockStyle);
            cell1.setCellStyle(dataStyle);
            cell1.setCellValue(paperArchivesDetailResult.getStudentCode());

            XSSFCell cell2 = row.createCell(2);
            cell2.setCellStyle(lockStyle);
            cell2.setCellStyle(dataStyle);
            cell2.setCellValue(paperArchivesDetailResult.getMajorName());

            XSSFCell cell3 = row.createCell(3);
            cell3.setCellStyle(lockStyle);
            cell3.setCellStyle(dataStyle);
            cell3.setCellValue(paperArchivesDetailResult.getClazzName());

            XSSFCell cell4 = row.createCell(4);
            cell4.setCellStyle(lockStyle);
            cell4.setCellStyle(dataStyle);
            cell4.setCellValue(paperArchivesDetailResult.getCourseName());

            XSSFCell cell5 = row.createCell(5);
            cell5.setCellStyle(lockStyle);
            cell5.setCellStyle(dataStyle);
            cell5.setCellValue(paperArchivesDetailResult.getTeacherName());

            XSSFCell cell6 = row.createCell(6);
            cell6.setCellStyle(lockStyle);
            cell6.setCellStyle(dataStyle);
            cell6.setCellValue(paperArchivesDetailResult.getTeachClazzName());

            XSSFCell cell7 = row.createCell(7);
            cell7.setCellStyle(lockStyle);
            cell7.setCellStyle(dataStyle);
            cell7.setCellValue(paperArchivesDetailResult.getBindCount());

            XSSFCell cell8 = row.createCell(8);
            cell8.setCellStyle(lockStyle);
            cell8.setCellStyle(dataStyle);
            cell8.setCellValue(successMap.get(paperArchivesDetailResult.getPaperScanTaskDetailId()));

            XSSFCell cell9 = row.createCell(9);
            cell9.setCellStyle(lockStyle);
            cell9.setCellStyle(dataStyle);
            cell9.setCellValue(errorMap.get(paperArchivesDetailResult.getPaperScanTaskDetailId()));
        }

        for (int i = 0; i < fieldsNameList.length; i++) {
            sheet.autoSizeColumn(i);
            sheet.setColumnWidth(i, sheet.getColumnWidth(i) * 17 / 10);
        }

        // sheet添加保护，这个一定要否则光锁定还是可以编辑的
        sheet.protectSheet(SystemConstant.EXCEL_PROTECT_KEY);

        File file = new File(zipLocalRootPath, fileName);
        FileOutputStream fout = new FileOutputStream(file);
        wb.write(fout);
        fout.close();
    }
}
