package com.qmth.paper.library.common.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.paper.library.common.base.BaseEntity;
import com.qmth.paper.library.common.bean.dto.excel.BasicStudentImportDto;
import com.qmth.paper.library.common.bean.dto.excel.DescribeImportDto;
import com.qmth.paper.library.common.bean.params.BasicStudentParams;
import com.qmth.paper.library.common.bean.result.BasicStudentResult;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.entity.BasicStudent;
import com.qmth.paper.library.common.entity.SysOrg;
import com.qmth.paper.library.common.entity.SysUser;
import com.qmth.paper.library.common.enums.ExceptionResultEnum;
import com.qmth.paper.library.common.enums.OrgTypeEnum;
import com.qmth.paper.library.common.mapper.BasicStudentMapper;
import com.qmth.paper.library.common.service.BasicStudentService;
import com.qmth.paper.library.common.service.SysOrgService;
import com.qmth.paper.library.common.util.ServletUtil;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.LinkedMultiValueMap;

import javax.annotation.Resource;
import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * <p>
 * 学校id 服务实现类
 * </p>
 *
 * @author wangliang
 * @since 2021-08-02
 */
@Service
public class BasicStudentServiceImpl extends ServiceImpl<BasicStudentMapper, BasicStudent> implements BasicStudentService {
    @Resource
    private BasicStudentMapper basicStudentMapper;
    @Resource
    private SysOrgService sysOrgService;

    @Override
    public IPage<BasicStudentResult> basicStudentPage(String queryParams, Long collegeId, String majorName, String clazzName, int pageNumber, int pageSize) {
        Long schoolId = SystemConstant.convertIdToLong(ServletUtil.getRequestHeaderSchoolId().toString());
        queryParams = SystemConstant.translateSpecificSign(queryParams);
        return basicStudentMapper.findBasicStudentPage(new Page<>(pageNumber, pageSize), queryParams, schoolId, collegeId, majorName, clazzName, null);
    }

    @Override
    public BasicStudentResult findById(Long id) {
        BasicStudentResult basicStudentResult = null;
        if (SystemConstant.longNotNull(id)) {
            basicStudentResult = this.baseMapper.findById(id);
        }
        return basicStudentResult;
    }

    @Override
    public List<BasicStudentResult> basicStudentList(Long schoolId, Long collegeId, String majorName, String clazzName, List<String> studentCodeList) {
        return this.baseMapper.findBasicStudentList(schoolId, collegeId, majorName, clazzName, studentCodeList);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Long saveBasicStudent(BasicStudentParams basicStudentParams, SysUser requestUser) {
        List<BasicStudentParams> basicStudentParamsList = new ArrayList<>();
        basicStudentParamsList.add(basicStudentParams);
        BasicStudent basicStudent = this.editEntityHelp(basicStudentParamsList, requestUser).get(0);
        this.saveOrUpdate(basicStudent);
        return basicStudent.getId();
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Boolean removeBasicStudentBatch(List<Long> idList) {
        if (idList.isEmpty()) {
            throw ExceptionResultEnum.ERROR.exception("请选择要删除的目标");
        }
        List<BasicStudent> basicStudentList = this.basicStudentMapper.listBindByStudentId(idList);
        if(!basicStudentList.isEmpty()){
            List<String> studentCodes = basicStudentList.stream().map(BasicStudent::getStudentCode).collect(Collectors.toList());
            throw ExceptionResultEnum.ERROR.exception("有学生已绑定图片，学号："+ String.join(",", studentCodes));
        }
        // 删除基础学生
        return this.remove(new QueryWrapper<BasicStudent>().lambda().in(BasicStudent::getId, idList));
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Boolean removeBasicStudentByCondition(String queryParams, Long collegeId, String majorName, String clazzName) {
        LambdaQueryWrapper<BasicStudent> basicStudentQueryWrapper = new QueryWrapper<BasicStudent>().lambda();
        if (SystemConstant.strNotNull(queryParams)) {
            basicStudentQueryWrapper.and(e -> e.like(BasicStudent::getStudentName, queryParams).or().like(BasicStudent::getStudentCode, queryParams));
        }
        if (SystemConstant.longNotNull(collegeId)) {
            basicStudentQueryWrapper.eq(BasicStudent::getBelongOrgId, collegeId);
        }
        if (SystemConstant.strNotNull(majorName)) {
            basicStudentQueryWrapper.eq(BasicStudent::getMajorName, majorName);
        }
        if (SystemConstant.strNotNull(clazzName)) {
            basicStudentQueryWrapper.eq(BasicStudent::getClazzName, clazzName);
        }
        List<BasicStudent> willDeleteStudent = this.list(basicStudentQueryWrapper);

        // 删除基础学生
        if (willDeleteStudent.size() > 0) {
            Set<Long> idSet = willDeleteStudent.stream().map(BaseEntity::getId).collect(Collectors.toSet());
            this.removeByIds(idSet);
        }
        return true;
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public Map<String, Object> executeBasicStudentImportLogic(List<LinkedMultiValueMap<Integer, Object>> finalList, Map<String, Object> map) {
        SysUser sysUser = (SysUser) map.get(SystemConstant.SYS_USER);
        Long schoolId = sysUser.getSchoolId();
        for (int i = 0; i < finalList.size(); i++) {
            LinkedMultiValueMap<Integer, Object> excelMap = finalList.get(i);
            List<Object> basicStudentImportDtoList = excelMap.get(i);

            assert basicStudentImportDtoList != null;
            if (basicStudentImportDtoList.get(0) instanceof DescribeImportDto) {
                continue;
            }
            List<BasicStudentImportDto> datasource = basicStudentImportDtoList.stream().map(e -> {
                BasicStudentImportDto basicStudentImportDto = new BasicStudentImportDto();
                BeanUtils.copyProperties(e, basicStudentImportDto);
                return basicStudentImportDto;
            }).collect(Collectors.toList());

            Map<String, Long> collegeMap = new HashMap<>();
            // 学校级机构
            SysOrg schoolOrg = sysOrgService.getOne(new QueryWrapper<SysOrg>().lambda().eq(SysOrg::getSchoolId, schoolId).eq(SysOrg::getType, OrgTypeEnum.SCHOOL));
            if (Objects.isNull(schoolOrg)) {
                throw ExceptionResultEnum.ERROR.exception("未找到学校级机构");
            }
            Long schoolOrgId = schoolOrg.getId();
            // 学校下所有二级机构集合
            List<SysOrg> secondaryOrgList = sysOrgService.list(new QueryWrapper<SysOrg>()
                            .lambda()
                            .eq(SysOrg::getSchoolId, schoolId)
                            .eq(SysOrg::getParentId, schoolOrgId))
                    .stream()
                    .filter(e -> !OrgTypeEnum.PRINTING_HOUSE.equals(e.getType()))
                    .collect(Collectors.toList());

            List<BasicStudentParams> basicStudentParamsList = datasource.stream().flatMap(e -> {
                String collegeName = e.getCollegeName();
                // 学院
                Long collegeId = null;
                if (SystemConstant.strNotNull(collegeName)) {
                    if (collegeMap.containsKey(collegeName)) {
                        collegeId = collegeMap.get(collegeName);
                    } else {
                        List<SysOrg> effectList = secondaryOrgList.stream().filter(n -> collegeName.equals(n.getName())).distinct().collect(Collectors.toList());
                        if (effectList.size() > 1) {
                            throw ExceptionResultEnum.ERROR.exception("机构数据异常");
                        }

                        if (effectList.size() == 0) {
                            // 新增一个机构
                            SysOrg addOrg = new SysOrg();
                            addOrg.insertInfo(sysUser.getId());
                            addOrg.setSchoolId(schoolId);
                            addOrg.setParentId(schoolOrgId);
                            addOrg.setName(collegeName);
                            sysOrgService.save(addOrg);
                            collegeId = addOrg.getId();
                        } else {
                            collegeId = effectList.get(0).getId();
                        }
                        collegeMap.put(collegeName, collegeId);
                    }
                }

                String studentCode = e.getStudentCode();
                BasicStudentParams basicStudentParams = new BasicStudentParams();
                BasicStudent tmp = this.getOne(new QueryWrapper<BasicStudent>().lambda()
                        .eq(BasicStudent::getSchoolId, schoolId)
                        .eq(BasicStudent::getEnable, true)
                        .eq(BasicStudent::getStudentCode, studentCode));
                if (Objects.nonNull(tmp)) {
                    basicStudentParams.setId(tmp.getId());
                }
                basicStudentParams.setStudentName(e.getStudentName());
                basicStudentParams.setStudentCode(e.getStudentCode());
                basicStudentParams.setPhoneNumber(e.getPhoneNumber());
                basicStudentParams.setCollegeId(collegeId);
                basicStudentParams.setMajorName(e.getMajorName());
                basicStudentParams.setClazzName(e.getClazzName());
                return Stream.of(basicStudentParams);
            }).collect(Collectors.toList());
            this.saveOrUpdateBatch(this.editEntityHelp(basicStudentParamsList, sysUser));
            map.put("dataCount", datasource.size());
        }
        return map;
    }

    /**
     * 学生保存助手方法（应对学生保存和导入批量保存）
     *
     * @param basicStudentParamsList 学生参数
     * @param sysUser                操作人
     * @return 结果
     */
    private List<BasicStudent> editEntityHelp(List<BasicStudentParams> basicStudentParamsList, SysUser sysUser) {
        Long schoolId = sysUser.getSchoolId();
        List<BasicStudent> editEntityList = new ArrayList<>();
        for (BasicStudentParams basicStudentParams : basicStudentParamsList) {
            // 普通参数
            String studentName = basicStudentParams.getStudentName();
            String studentCode = basicStudentParams.getStudentCode();
            String phoneNumber = basicStudentParams.getPhoneNumber();
            String majorName = basicStudentParams.getMajorName();
            String clazzName = basicStudentParams.getClazzName();
            Long collegeId = basicStudentParams.getCollegeId();

            // 班级验证
            Long id = basicStudentParams.getId();
            // 检验学号在学校的唯一性
            BasicStudent checkCode = this.getOne(new QueryWrapper<BasicStudent>().lambda()
                    .eq(BasicStudent::getSchoolId, schoolId)
                    .eq(BasicStudent::getStudentCode, studentCode)
                    .eq(BasicStudent::getEnable, true));
            if (Objects.nonNull(checkCode)) {
                if (!checkCode.getId().equals(id)) {
                    throw ExceptionResultEnum.ERROR.exception("学生编号【" + studentCode + "】重复");
                }
            }

            // 检验有值的电话在学校的唯一性
            if (SystemConstant.strNotNull(phoneNumber)) {
                BasicStudent checkPhone = this.getOne(new QueryWrapper<BasicStudent>().lambda()
                        .eq(BasicStudent::getSchoolId, schoolId)
                        .eq(BasicStudent::getPhoneNumber, phoneNumber)
                        .eq(BasicStudent::getEnable, true));
                if (Objects.nonNull(checkPhone)) {
                    if (!checkPhone.getId().equals(id)) {
                        throw ExceptionResultEnum.ERROR.exception("学生电话【" + phoneNumber + "】重复");
                    }
                }
            }

            // 组装基础参数
            Long orgId;
            BasicStudent basicStudent = new BasicStudent();
            basicStudent.setStudentCode(studentCode);
            basicStudent.setStudentName(studentName);
            basicStudent.setPhoneNumber(phoneNumber);
            basicStudent.setBelongOrgId(collegeId);
            basicStudent.setMajorName(majorName);
            basicStudent.setClazzName(clazzName);
            basicStudent.setSchoolId(schoolId);

            // 保存
            if (!SystemConstant.longNotNull(id)) {
                // id为空 -> 新增
                // 获取分布式id
                orgId = sysUser.getOrgId();
                id = SystemConstant.getDbUuid();
                basicStudent.setId(id);

                basicStudent.setCreateId(sysUser.getId());
            } else {
                // id不为空 -> 更新
                BasicStudent old = this.getById(id);
                if (Objects.isNull(old) || old.getEnable().equals(false)) {
                    throw ExceptionResultEnum.ERROR.exception("学生主键不存在或被禁用");
                }
                orgId = old.getOrgId();
                basicStudent.setId(id);
                basicStudent.setUpdateId(sysUser.getId());
            }
            basicStudent.setOrgId(orgId);
            editEntityList.add(basicStudent);
        }
        return editEntityList;
    }
}
