package com.qmth.paper.library.common.service.impl;

import com.alibaba.fastjson.JSON;
import com.qmth.paper.library.common.bean.dto.syssetting.SettingObject;
import com.qmth.paper.library.common.bean.dto.syssetting.SimpleObject;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.entity.SysSetting;
import com.qmth.paper.library.common.entity.SysSettingGlobal;
import com.qmth.paper.library.common.entity.TBSession;
import com.qmth.paper.library.common.service.CommonCacheService;
import com.qmth.paper.library.common.service.SysSettingGlobalService;
import com.qmth.paper.library.common.service.SysSettingService;
import com.qmth.paper.library.common.service.TBSessionService;
import org.springframework.cache.annotation.CacheEvict;
import org.springframework.cache.annotation.CachePut;
import org.springframework.cache.annotation.Cacheable;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Service
public class CommonCacheServiceImpl implements CommonCacheService {

    @Resource
    TBSessionService tbSessionService;

    @Resource
    SysSettingService sysSettingService;

    @Resource
    SysSettingGlobalService sysSettingGlobalService;

    @Override
    @CachePut(value = SystemConstant.CACHE_NAME, key = "'tbSession' + #sessionId")
    public TBSession saveTbSession(String sessionId, TBSession tbSession) {
        return tbSession;
    }

    @Override
    @Cacheable(value = SystemConstant.CACHE_NAME, key = "'tbSession' + #sessionId")
    public TBSession getTbSession(String sessionId) {
        return tbSessionService.getById(sessionId);
    }

    @Override
    @CacheEvict(value = SystemConstant.CACHE_NAME, key = "'tbSession' + #sessionId")
    public String removeTbSession(String sessionId) {
        return null;
    }

    @Override
    @Cacheable(value = SystemConstant.CACHE_NAME, key = "'sysSetting' + #schoolId")
    public Map<String, String> getSysSetting(Long schoolId) {
        SysSetting sysSetting = sysSettingService.getBySchoolId(schoolId);
        String parameterObject = sysSetting.getParameterObject();
        List<SettingObject> settingObjects = JSON.parseArray(parameterObject, SettingObject.class);
        Map<String, String> map = new HashMap<>();
        for (SettingObject settingObject : settingObjects) {
            for (SimpleObject simpleObject : settingObject.getData()) {
                map.put(simpleObject.getCode(), simpleObject.getValue());
            }
        }
        return map;
    }

    @Override
    @CacheEvict(value = SystemConstant.CACHE_NAME, key = "'sysSetting' + #schoolId")
    public String removeSysSetting(Long schoolId) {
        return null;
    }

    @Override
    @Cacheable(value = SystemConstant.CACHE_NAME, key = "'sysSetting'")
    public Map<String, String> getSysSettingGlobal() {
        SysSettingGlobal sysSettingGlobal = sysSettingGlobalService.getOnlyOne();
        String parameterObject = sysSettingGlobal.getParameterObject();
        List<SettingObject> settingObjects = JSON.parseArray(parameterObject, SettingObject.class);
        Map<String, String> map = new HashMap<>();
        for (SettingObject settingObject : settingObjects) {
            for (SimpleObject simpleObject : settingObject.getData()) {
                map.put(simpleObject.getCode(), simpleObject.getValue());
            }
        }
        return map;
    }

    @Override
    @CacheEvict(value = SystemConstant.CACHE_NAME, key = "'sysSetting'")
    public String removeSysSettingGlobal() {
        return null;
    }
}
