package com.qmth.paper.library.api;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.paper.library.business.bean.result.DictionaryResult;
import com.qmth.paper.library.business.bean.result.EditResult;
import com.qmth.paper.library.business.bean.result.SelectResult;
import com.qmth.paper.library.business.enums.DictionaryEnum;
import com.qmth.paper.library.business.service.PaperArchivesService;
import com.qmth.paper.library.business.service.PaperArchivesTypeService;
import com.qmth.paper.library.business.service.PaperScanTaskService;
import com.qmth.paper.library.common.contant.ApiPrefixConstant;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.entity.BasicSemester;
import com.qmth.paper.library.common.entity.BasicStudent;
import com.qmth.paper.library.common.service.BasicSemesterService;
import com.qmth.paper.library.common.service.BasicStudentService;
import com.qmth.paper.library.common.service.SysOrgService;
import com.qmth.paper.library.common.util.Result;
import com.qmth.paper.library.common.util.ResultUtil;
import com.qmth.paper.library.common.util.ServletUtil;
import io.swagger.annotations.*;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * <p>
 * 查询 前端控制器
 * </p>
 */
@Api(tags = "查询条件Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + ApiPrefixConstant.PREFIX_COMMON)
@Validated
public class ConditionController {

    @Resource
    PaperArchivesService paperArchivesService;

    @Resource
    BasicSemesterService basicSemesterService;

    @Resource
    PaperArchivesTypeService paperArchivesTypeService;

    @Resource
    PaperScanTaskService paperScanTaskService;

    @Resource
    SysOrgService sysOrgService;

    @Resource
    BasicStudentService basicStudentService;

    @ApiOperation(value = "查询条件-学期")
    @PostMapping("/semester/query")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result querySemester() {
        List<BasicSemester> semesters = basicSemesterService.querySemester();
        List<SelectResult> resultList = semesters.stream().map(m -> {
            SelectResult result = new SelectResult();
            result.setId(String.valueOf(m.getId()));
            result.setCode(m.getCode());
            result.setName(m.getName());
            return result;
        }).collect(Collectors.toList());
        return ResultUtil.ok(resultList);
    }

    @ApiOperation(value = "查询条件-档案")
    @PostMapping("/archives/query")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result queryArchives(@ApiParam(value = "学期ID") @RequestParam(required = false) Long semesterId) {
        return ResultUtil.ok(paperArchivesService.queryArchives(semesterId));
    }

    @ApiOperation(value = "查询条件-档案管理员")
    @PostMapping("/manager_user/query")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result queryManagerUser() {
        return ResultUtil.ok(paperArchivesService.queryManagerUser());
    }

    @ApiOperation(value = "查询条件-档案管理部门")
    @PostMapping("/manager_org/query")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result queryManagerOrg(@RequestParam(value = "semesterId", required = false) Long semesterId) {
        return ResultUtil.ok(paperArchivesService.queryManagerOrg(semesterId));
    }

    @ApiOperation(value = "查询条件-档案类型")
    @PostMapping("/archives_type/query")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result queryArchivesType() {
        return ResultUtil.ok(paperArchivesTypeService.queryArchivesType());
    }

    @ApiOperation(value = "查询条件-课程")
    @PostMapping("/course/query")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = EditResult.class)})
    public Result queryCourse(@ApiParam(value = "档案id") @RequestParam(value = "paperArchivesId", required = false) Long paperArchivesId,
                              @ApiParam(value = "学期id") @RequestParam(value = "semesterId", required = false) Long semesterId) {
        List<SelectResult> courseList = paperScanTaskService.queryCourse(paperArchivesId, semesterId);
        return ResultUtil.ok(courseList);
    }

    @ApiOperation(value = "查询条件-教学班")
    @PostMapping("/teach_clazz/query")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = EditResult.class)})
    public Result queryTeachClazz(@ApiParam(value = "档案id") @RequestParam(value = "paperArchivesId", required = false) Long paperArchivesId,
                                  @ApiParam(value = "课程") @RequestParam(value = "courseName", required = false) String courseName) {
        List<SelectResult> teachClazzList = paperScanTaskService.queryDataTeachClazz(paperArchivesId, courseName);
        return ResultUtil.ok(teachClazzList);
    }

    @ApiOperation(value = "查询条件-扫描任务")
    @PostMapping("/scan_task/query")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = EditResult.class)})
    public Result queryScanTask(@ApiParam(value = "档案id") @RequestParam(value = "paperArchivesId", required = false) Long paperArchivesId) {
        List<SelectResult> scanTaskList = paperScanTaskService.queryScanTask(paperArchivesId);
        return ResultUtil.ok(scanTaskList);
    }

    @ApiOperation(value = "查询条件-学生查询条件级联查询（学生学院-专业-班级）")
    @RequestMapping(value = "/basic_student/condition", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result findDictionaryList(@ApiParam(value = "学院id") @RequestParam(required = false) String collegeId,
                                     @ApiParam(value = "专业名称") @RequestParam(required = false) String majorName,
                                     @ApiParam(value = "查询字典对象", required = true) @RequestParam DictionaryEnum dictionaryEnum) {
        Long schoolId = SystemConstant.convertIdToLong(ServletUtil.getRequestHeaderSchoolId().toString());
        QueryWrapper<BasicStudent> studentQuery = new QueryWrapper<>();
        studentQuery.lambda().eq(BasicStudent::getSchoolId, schoolId);
        if (SystemConstant.longNotNull(SystemConstant.convertIdToLong(collegeId))) {
            Long orgId = SystemConstant.convertIdToLong(collegeId);
            studentQuery.lambda().eq(BasicStudent::getBelongOrgId, orgId);
        }
        if (SystemConstant.strNotNull(majorName)) {
            studentQuery.lambda().eq(BasicStudent::getMajorName, majorName);
        }
        List<DictionaryResult> dictionaryResultList = new ArrayList<>();
        switch (dictionaryEnum) {
            case COLLEGE:
                dictionaryResultList = sysOrgService.findCollegeLevelOrgList(schoolId).stream().flatMap(e -> {
                    DictionaryResult dictionaryResult = new DictionaryResult();
                    dictionaryResult.setId(e.getId());
                    dictionaryResult.setCode(e.getCode());
                    dictionaryResult.setName(e.getName());
                    return Stream.of(dictionaryResult);
                }).collect(Collectors.toList());
                break;
            case MAJOR:
                dictionaryResultList = basicStudentService.list(studentQuery).stream().map(BasicStudent::getMajorName).distinct().flatMap(e -> {
                    DictionaryResult dictionaryResult = new DictionaryResult();
                    dictionaryResult.setName(e);
                    return Stream.of(dictionaryResult);
                }).collect(Collectors.toList());
                break;
            case CLAZZ:
                dictionaryResultList = basicStudentService.list(studentQuery).stream().map(BasicStudent::getClazzName).distinct().flatMap(e -> {
                    DictionaryResult dictionaryResult = new DictionaryResult();
                    dictionaryResult.setName(e);
                    return Stream.of(dictionaryResult);
                }).collect(Collectors.toList());
                break;
        }
        return ResultUtil.ok(dictionaryResultList);
    }
}
