package com.qmth.paper.library.api;


import com.alibaba.fastjson.JSON;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.paper.library.business.bean.result.EditResult;
import com.qmth.paper.library.business.entity.PaperArchives;
import com.qmth.paper.library.business.service.PaperArchivesService;
import com.qmth.paper.library.business.templete.execute.AsyncDownloadPaperService;
import com.qmth.paper.library.common.bean.params.DownLoadPaperParams;
import com.qmth.paper.library.common.contant.ApiPrefixConstant;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.entity.SysUser;
import com.qmth.paper.library.common.entity.TBTask;
import com.qmth.paper.library.common.enums.TaskTypeEnum;
import com.qmth.paper.library.common.service.TBTaskService;
import com.qmth.paper.library.common.util.Result;
import com.qmth.paper.library.common.util.ResultUtil;
import com.qmth.paper.library.common.util.ServletUtil;
import io.swagger.annotations.*;
import org.springframework.validation.BindingResult;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import java.util.Map;
import java.util.Objects;

/**
 * <p>
 * 档案管理表 前端控制器
 * </p>
 */
@Api(tags = "档案管理表controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + ApiPrefixConstant.PREFIX_PAPER + "/archives")
@Validated
public class PaperArchivesController {
    @Resource
    private PaperArchivesService paperArchivesService;

    @Resource
    private TBTaskService tbTaskService;

    @Resource
    private AsyncDownloadPaperService asyncDownloadPaperService;

    @ApiOperation(value = "分页查询")
    @PostMapping("/page")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result page(@ApiParam(value = "档案所属学期") @RequestParam(required = false) Long semesterId,
                       @ApiParam(value = "档案管理部门") @RequestParam(required = false) Long managerOrgId,
                       @ApiParam(value = "档案类型") @RequestParam(required = false) Long archivesTypeId,
                       @ApiParam(value = "档案名称") @RequestParam(required = false) String archivesName,
                       @ApiParam(value = "分页页码", required = true) @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                       @ApiParam(value = "分页数", required = true) @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(paperArchivesService.pageData(semesterId, managerOrgId, archivesTypeId, archivesName, pageNumber, pageSize));
    }

    @ApiOperation(value = "新增/编辑")
    @PostMapping("/save")
    @ApiResponses({@ApiResponse(code = 200, message = "新增成功", response = EditResult.class)})
    public Result save(@Valid @RequestBody PaperArchives paperArchives, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultUtil.error(bindingResult.getAllErrors().get(0).getDefaultMessage());
        }
        return ResultUtil.ok(paperArchivesService.saveData(paperArchives));
    }

    @ApiOperation(value = "查看详情")
    @PostMapping("/page_detail")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result pageDetail(@ApiParam(value = "档案ID") @RequestParam Long paperArchivesId,
                             @ApiParam(value = "学院") @RequestParam(required = false) Long belongOrgId,
                             @ApiParam(value = "专业") @RequestParam(required = false) String majorName,
                             @ApiParam(value = "班级") @RequestParam(required = false) String clazzName,
                             @ApiParam(value = "课程") @RequestParam(required = false) String courseName,
                             @ApiParam(value = "任课老师") @RequestParam(required = false) String teacherName,
                             @ApiParam(value = "教学班") @RequestParam(required = false) String teachClazzName,
                             @ApiParam(value = "是否绑定") @RequestParam(required = false) Boolean isBind,
                             @ApiParam(value = "模糊查询（姓名/学号）") @RequestParam(required = false) String param,
                             @ApiParam(value = "分页页码", required = true) @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                             @ApiParam(value = "分页数", required = true) @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(paperArchivesService.pageDetail(paperArchivesId, belongOrgId, majorName, clazzName, courseName, teacherName, teachClazzName, isBind, param, pageNumber, pageSize));
    }


    @ApiOperation(value = "删除")
    @PostMapping("/delete")
    @ApiResponses({@ApiResponse(code = 200, message = "删除成功", response = Result.class)})
    public Result delete(@ApiParam(value = "主键") @RequestParam String ids) {
        return ResultUtil.ok(paperArchivesService.delete(ids));
    }

    @ApiOperation(value = "批量下载")
    @PostMapping("/paper_download")
    @ApiResponses({@ApiResponse(code = 200, message = "下载成功", response = EditResult.class)})
    public Result paperDownload(@RequestBody DownLoadPaperParams downLoadPaperParams) {
        String remark = JSON.toJSONString(downLoadPaperParams);
        Map<String, Object> map = tbTaskService.saveTask(TaskTypeEnum.PAPER_DOWNLOAD, remark, (SysUser) ServletUtil.getRequestUser());
        asyncDownloadPaperService.exportTask(map);
        TBTask tbTask = Objects.nonNull(map.get(SystemConstant.TASK)) ? (TBTask) map.get(SystemConstant.TASK) : null;
        return Objects.nonNull(tbTask) ? ResultUtil.ok(new EditResult(tbTask.getId())) : ResultUtil.error("创建任务失败");
    }


}
