package com.qmth.paper.library.api;


import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.paper.library.business.bean.result.EditResult;
import com.qmth.paper.library.business.service.PaperLibraryService;
import com.qmth.paper.library.common.contant.ApiPrefixConstant;
import com.qmth.paper.library.common.contant.SystemConstant;
import com.qmth.paper.library.common.util.Result;
import com.qmth.paper.library.common.util.ResultUtil;
import io.swagger.annotations.*;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;

/**
 * <p>
 * 数据检查 前端控制器
 * </p>
 */
@Api(tags = "数据检查Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + ApiPrefixConstant.PREFIX_PAPER + "/library")
@Validated
public class PaperLibraryController {
    @Resource
    private PaperLibraryService paperLibraryService;

    @ApiOperation(value = "分页查询-未处理")
    @PostMapping("/page_unbind")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result pageUnbind(@ApiParam(value = "任务") @RequestParam(required = false) Long paperScanTaskId,
                             @ApiParam(value = "分页页码", required = true) @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                             @ApiParam(value = "分页数", required = true) @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(paperLibraryService.pageUnbindData(paperScanTaskId, pageNumber, pageSize));
    }

    @ApiOperation(value = "分页查询-未处理数量")
    @PostMapping("/count_unbind")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result countUnbind(@ApiParam(value = "任务") @RequestParam(required = false) Long paperScanTaskId) {
        return ResultUtil.ok(paperLibraryService.countUnbindData(paperScanTaskId));
    }

    @ApiOperation(value = "分页查询-已处理")
    @PostMapping("/page_bind")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result pageBind(@ApiParam(value = "任务") @RequestParam(required = false) Long paperScanTaskId,
                           @ApiParam(value = "分页页码", required = true) @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                           @ApiParam(value = "分页数", required = true) @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(paperLibraryService.pageBindData(paperScanTaskId, pageNumber, pageSize));
    }

    @ApiOperation(value = "分页查询-已处理数量")
    @PostMapping("/count_bind")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result countBind(@ApiParam(value = "任务") @RequestParam(required = false) Long paperScanTaskId) {
        return ResultUtil.ok(paperLibraryService.countBindData(paperScanTaskId));
    }

    @ApiOperation(value = "分页查询-异常")
    @PostMapping("/page_abnormal")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result pageAbnormal(@ApiParam(value = "任务") @RequestParam(required = false) Long paperScanTaskId,
                               @ApiParam(value = "分页页码", required = true) @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                               @ApiParam(value = "分页数", required = true) @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(paperLibraryService.pageAbnormalData(paperScanTaskId, pageNumber, pageSize));
    }

    @ApiOperation(value = "分页查询-异常数量")
    @PostMapping("/count_abnormal")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result countAbnormal(@ApiParam(value = "任务") @RequestParam(required = false) Long paperScanTaskId) {
        return ResultUtil.ok(paperLibraryService.countAbnormalData(paperScanTaskId));
    }

    @ApiOperation(value = "查询考生图片集合")
    @PostMapping("/list_student_picture")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result listStudentPicture(@ApiParam(value = "扫描任务详情ID（任务+考生）") @RequestParam Long paperScanTaskDetailId) {
        return ResultUtil.ok(paperLibraryService.listStudentPicture(paperScanTaskDetailId));
    }

    @ApiOperation(value = "绑定")
    @PostMapping("/bind")
    @ApiResponses({@ApiResponse(code = 200, message = "绑定成功", response = EditResult.class)})
    public Result save(@ApiParam(value = "扫描图片ID") @RequestParam Long paperLibraryId,
                       @ApiParam(value = "扫描任务详情ID（任务+考生）") @RequestParam Long paperScanTaskDetailId) {
        return ResultUtil.ok(paperLibraryService.bind(paperLibraryId, paperScanTaskDetailId));
    }

    @ApiOperation(value = "标记异常")
    @PostMapping("/abnormal")
    @ApiResponses({@ApiResponse(code = 200, message = "标记成功", response = EditResult.class)})
    public Result abnormal(@ApiParam(value = "扫描图片ID") @RequestParam Long paperLibraryId) {
        return ResultUtil.ok(paperLibraryService.abnormal(paperLibraryId));
    }

    @ApiOperation(value = "获取单条图片详情")
    @PostMapping("/get_paper_data")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result getAbnormalData(@ApiParam(value = "扫描图片ID") @RequestParam Long paperLibraryId) {
        return ResultUtil.ok(paperLibraryService.toAbnormalPaper(paperLibraryId));
    }

    @ApiOperation(value = "开始处理")
    @PostMapping("/get_bind_data")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result getBindData() {
        return ResultUtil.ok(paperLibraryService.toBindPaper());
    }

    @ApiOperation(value = "根据扫描任务ID查询学生")
    @PostMapping("/page_student")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result pageStudent(@ApiParam(value = "扫描任务ID") @RequestParam Long paperScanTaskId,
                              @ApiParam(value = "模糊查询（学号/姓名）") @RequestParam(required = false) String param,
                              @ApiParam(value = "是否开启全局匹配") @RequestParam(required = false) Boolean globalMatch,
                              @ApiParam(value = "分页页码", required = true) @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                              @ApiParam(value = "分页数", required = true) @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(paperLibraryService.pageStudent(paperScanTaskId, param, globalMatch, pageNumber, pageSize));
    }

    @ApiOperation(value = "根据学号查询所有任务下考生信息")
    @PostMapping("/list_by_student_code")
    @ApiResponses({@ApiResponse(code = 200, message = "查询成功", response = Result.class)})
    public Result listByStudentCode(@ApiParam(value = "学号") @RequestParam String studentCode,
                                    @ApiParam(value = "分页页码", required = true) @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                                    @ApiParam(value = "分页数", required = true) @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(paperLibraryService.listByStudentCode(studentCode, pageNumber, pageSize));
    }

    @ApiOperation(value = "OCR识别")
    @PostMapping("/ocr")
    @ApiResponses({@ApiResponse(code = 200, message = "识别成功", response = Result.class)})
    public Result ocr(@ApiParam(value = "图片id") @RequestParam Long paperLibraryId,
                      @ApiParam(value = "图片正反面") @RequestParam Integer index,
                      @ApiParam(value = "x") @RequestParam Integer x,
                      @ApiParam(value = "y") @RequestParam Integer y,
                      @ApiParam(value = "width") @RequestParam Integer width,
                      @ApiParam(value = "height") @RequestParam Integer height,
                      @ApiParam(value = "旋转角度") @RequestParam(defaultValue = "0") Integer rotate) {
        return ResultUtil.ok(paperLibraryService.ocr(paperLibraryId, index, x, y, width, height, rotate), null);
    }
}
